@@ -1,19 +1,26 @@
+# pylint: disable=too-many-lines
 """Data structure for using netcdf groups with xarray."""
-from collections import OrderedDict
+import uuid
+import warnings
+from collections import OrderedDict, defaultdict
 from collections.abc import Sequence
-from copy import copy as ccopy, deepcopy
+from copy import copy as ccopy
+from copy import deepcopy
 from datetime import datetime
 from html import escape
-import warnings
-import uuid
 
 import netCDF4 as nc
 import numpy as np
 import xarray as xr
-from xarray.core.options import OPTIONS
 
-from ..utils import _subset_list, HtmlTemplate
 from ..rcparams import rcParams
+from ..utils import HtmlTemplate, _subset_list, either_dict_or_kwargs
+from .base import _extend_xr_method, _make_json_serializable, dict_to_dataset
+
+try:
+    import ujson as json
+except ImportError:
+    import json
 
 SUPPORTED_GROUPS = [
     "posterior",
@@ -138,27 +145,32 @@ class InferenceData:
 
     def _repr_html_(self):
         """Make html representation of InferenceData object."""
-        display_style = OPTIONS["display_style"]
-        if display_style == "text":
+        try:
+            from xarray.core.options import OPTIONS
+
+            display_style = OPTIONS["display_style"]
+            if display_style == "text":
+                html_repr = f"<pre>{escape(repr(self))}</pre>"
+            else:
+                elements = "".join(
+                    [
+                        HtmlTemplate.element_template.format(
+                            group_id=group + str(uuid.uuid4()),
+                            group=group,
+                            xr_data=getattr(  # pylint: disable=protected-access
+                                self, group
+                            )._repr_html_(),
+                        )
+                        for group in self._groups_all
+                    ]
+                )
+                formatted_html_template = (  # pylint: disable=possibly-unused-variable
+                    HtmlTemplate.html_template.format(elements)
+                )
+                css_template = HtmlTemplate.css_template  # pylint: disable=possibly-unused-variable
+                html_repr = "%(formatted_html_template)s%(css_template)s" % locals()
+        except:  # pylint: disable=bare-except
             html_repr = f"<pre>{escape(repr(self))}</pre>"
-        else:
-            elements = "".join(
-                [
-                    HtmlTemplate.element_template.format(
-                        group_id=group + str(uuid.uuid4()),
-                        group=group,
-                        xr_data=getattr(  # pylint: disable=protected-access
-                            self, group
-                        )._repr_html_(),
-                    )
-                    for group in self._groups_all
-                ]
-            )
-            formatted_html_template = HtmlTemplate.html_template.format(  # pylint: disable=possibly-unused-variable
-                elements
-            )
-            css_template = HtmlTemplate.css_template  # pylint: disable=possibly-unused-variable
-            html_repr = "%(formatted_html_template)s%(css_template)s" % locals()
         return html_repr
 
     def __delattr__(self, group):
@@ -173,6 +185,25 @@ class InferenceData:
     def _groups_all(self):
         return self._groups + self._groups_warmup
 
+    def __iter__(self):
+        """Iterate over groups in InferenceData object."""
+        for group in self._groups_all:
+            yield group
+
+    def groups(self):
+        """Return all groups present in InferenceData object."""
+        return self._groups_all
+
+    def values(self):
+        """Xarray Datasets present in InferenceData object."""
+        for group in self._groups_all:
+            yield getattr(self, group)
+
+    def items(self):
+        """Yield groups and corresponding datasets present in InferenceData object."""
+        for group in self._groups_all:
+            yield (group, getattr(self, group))
+
     @staticmethod
     def from_netcdf(filename):
         """Initialize object from a netcdf file.
@@ -241,12 +272,95 @@ class InferenceData:
             empty_netcdf_file.close()
         return filename
 
+    def to_dict(self, groups=None, filter_groups=None):
+        """Convert InferenceData to a dictionary following xarray naming conventions.
+
+        Parameters
+        ----------
+        groups : list, optional
+            Write only these groups to netcdf file.
+
+        Returns
+        -------
+        dict
+            A dictionary containing all groups of InferenceData object.
+            When `data=False` return just the schema.
+        """
+        ret = defaultdict(dict)
+        attrs = None
+        if self._groups_all:  # check's whether a group is present or not.
+            if groups is None:
+                groups = self._group_names(groups, filter_groups)
+            else:
+                groups = [group for group in self._groups_all if group in groups]
+
+            for group in groups:
+                dataset = getattr(self, group)
+                data = {}
+                for var_name, dataarray in dataset.items():
+                    data[var_name] = dataarray.values
+                    dims = []
+                    for coord_name, coord_values in dataarray.coords.items():
+                        if coord_name not in ("chain", "draw") and not coord_name.startswith(
+                            var_name + "_dim_"
+                        ):
+                            dims.append(coord_name)
+                            ret["coords"][coord_name] = coord_values.values
+
+                    if group in (
+                        "predictions",
+                        "predictions_constant_data",
+                    ):
+                        dims_key = "pred_dims"
+                    else:
+                        dims_key = "dims"
+                    if len(dims) > 0:
+                        ret[dims_key][var_name] = dims
+                    ret[group] = data
+                if attrs is None:
+                    attrs = dataset.attrs
+                elif attrs != dataset.attrs:
+                    warnings.warn(
+                        "The attributes are not same for all groups."
+                        " Considering only the first group `attrs`"
+                    )
+
+        ret["attrs"] = attrs
+        return ret
+
+    def to_json(self, filename, **kwargs):
+        """Write InferenceData to a json file.
+
+        Parameters
+        ----------
+        filename : str
+            Location to write to
+        kwargs : dict
+            kwargs passed to json.dump()
+
+        Returns
+        -------
+        str
+            Location of json file
+        """
+        idata_dict = _make_json_serializable(self.to_dict())
+
+        with open(filename, "w") as file:
+            json.dump(idata_dict, file, **kwargs)
+
+        return filename
+
     def __add__(self, other):
         """Concatenate two InferenceData objects."""
         return concat(self, other, copy=True, inplace=False)
 
     def sel(
-        self, groups=None, filter_groups=None, inplace=False, chain_prior=None, **kwargs,
+        self,
+        groups=None,
+        filter_groups=None,
+        inplace=False,
+        chain_prior=None,
+        **kwargs,
     ):
         """Perform an xarray selection on all groups.
 
@@ -262,6 +376,11 @@ class InferenceData:
         groups: str or list of str, optional
             Groups where the selection is to be applied. Can either be group names
             or metagroup names.
+        filter_groups: {None, "like", "regex"}, optional, default=None
+            If `None` (default), interpret groups as the real group or metagroup names.
+            If "like", interpret groups as substrings of the real group or metagroup names.
+            If "regex", interpret groups as regular expressions on the real group or
+            metagroup names. A la `pandas.filter`.
         inplace: bool, optional
             If ``True``, modify the InferenceData object inplace,
             otherwise, return the modified copy.
@@ -275,7 +394,7 @@ class InferenceData:
         -------
         InferenceData
             A new InferenceData object by default.
-            When `inplace==True` perform selection in place and return `None`
+            When `inplace==True` perform selection in-place and return `None`
 
         Examples
         --------
@@ -324,6 +443,432 @@ class InferenceData:
         else:
             return out
 
+    def isel(
+        self,
+        groups=None,
+        filter_groups=None,
+        inplace=False,
+        **kwargs,
+    ):
+        """Perform an xarray selection on all groups.
+
+        Loops groups to perform Dataset.isel(key=item)
+        for every kwarg if key is a dimension of the dataset.
+        One example could be performing a burn in cut on the InferenceData object
+        or discarding a chain. The selection is performed on all relevant groups (like
+        posterior, prior, sample stats) while non relevant groups like observed data are
+        omitted. See :meth:`xarray:xarray.Dataset.isel`
+
+        Parameters
+        ----------
+        groups: str or list of str, optional
+            Groups where the selection is to be applied. Can either be group names
+            or metagroup names.
+        filter_groups: {None, "like", "regex"}, optional, default=None
+            If `None` (default), interpret groups as the real group or metagroup names.
+            If "like", interpret groups as substrings of the real group or metagroup names.
+            If "regex", interpret groups as regular expressions on the real group or
+            metagroup names. A la `pandas.filter`.
+        inplace: bool, optional
+            If ``True``, modify the InferenceData object inplace,
+            otherwise, return the modified copy.
+        **kwargs: mapping
+            It must be accepted by :meth:`xarray:xarray.Dataset.isel`.
+
+        Returns
+        -------
+        InferenceData
+            A new InferenceData object by default.
+            When `inplace==True` perform selection in-place and return `None`
+
+        """
+        groups = self._group_names(groups, filter_groups)
+
+        out = self if inplace else deepcopy(self)
+        for group in groups:
+            dataset = getattr(self, group)
+            valid_keys = set(kwargs.keys()).intersection(dataset.dims)
+            dataset = dataset.isel(**{key: kwargs[key] for key in valid_keys})
+            setattr(out, group, dataset)
+        if inplace:
+            return None
+        else:
+            return out
+
+    def stack(
+        self,
+        dimensions=None,
+        groups=None,
+        filter_groups=None,
+        inplace=False,
+        **kwargs,
+    ):
+        """Perform an xarray stacking on all groups.
+
+        Stack any number of existing dimensions into a single new dimension.
+        Loops groups to perform Dataset.stack(key=value)
+        for every kwarg if value is a dimension of the dataset.
+        The selection is performed on all relevant groups (like
+        posterior, prior, sample stats) while non relevant groups like observed data are
+        omitted. See :meth:`xarray:xarray.Dataset.stack`
+
+        Parameters
+        ----------
+        dimensions: dict
+            Names of new dimensions, and the existing dimensions that they replace.
+        groups: str or list of str, optional
+            Groups where the selection is to be applied. Can either be group names
+            or metagroup names.
+        filter_groups: {None, "like", "regex"}, optional, default=None
+            If `None` (default), interpret groups as the real group or metagroup names.
+            If "like", interpret groups as substrings of the real group or metagroup names.
+            If "regex", interpret groups as regular expressions on the real group or
+            metagroup names. A la `pandas.filter`.
+        inplace: bool, optional
+            If ``True``, modify the InferenceData object inplace,
+            otherwise, return the modified copy.
+        **kwargs: mapping
+            It must be accepted by :meth:`xarray:xarray.Dataset.stack`.
+
+        Returns
+        -------
+        InferenceData
+            A new InferenceData object by default.
+            When `inplace==True` perform selection in-place and return `None`
+
+        """
+        groups = self._group_names(groups, filter_groups)
+
+        dimensions = {} if dimensions is None else dimensions
+        dimensions.update(kwargs)
+        out = self if inplace else deepcopy(self)
+        for group in groups:
+            dataset = getattr(self, group)
+            kwarg_dict = {}
+            for key, value in dimensions.items():
+                if not set(value).difference(dataset.dims):
+                    kwarg_dict[key] = value
+            dataset = dataset.stack(**kwarg_dict)
+            setattr(out, group, dataset)
+        if inplace:
+            return None
+        else:
+            return out
+
+    def unstack(self, dim=None, groups=None, filter_groups=None, inplace=False):
+        """Perform an xarray unstacking on all groups.
+
+        Unstack existing dimensions corresponding to MultiIndexes into multiple new dimensions.
+        Loops groups to perform Dataset.unstack(key=value).
+        The selection is performed on all relevant groups (like posterior, prior,
+        sample stats) while non relevant groups like observed data are omitted.
+        See :meth:`xarray:xarray.Dataset.unstack`
+
+        Parameters
+        ----------
+        dim: Hashable or iterable of Hashable, optional
+            Dimension(s) over which to unstack. By default unstacks all MultiIndexes.
+        groups: str or list of str, optional
+            Groups where the selection is to be applied. Can either be group names
+            or metagroup names.
+        filter_groups: {None, "like", "regex"}, optional, default=None
+            If `None` (default), interpret groups as the real group or metagroup names.
+            If "like", interpret groups as substrings of the real group or metagroup names.
+            If "regex", interpret groups as regular expressions on the real group or
+            metagroup names. A la `pandas.filter`.
+        inplace: bool, optional
+            If ``True``, modify the InferenceData object inplace,
+            otherwise, return the modified copy.
+
+        Returns
+        -------
+        InferenceData
+            A new InferenceData object by default.
+            When `inplace==True` perform selection in place and return `None`
+
+        """
+        groups = self._group_names(groups, filter_groups)
+        if isinstance(dim, str):
+            dim = [dim]
+
+        out = self if inplace else deepcopy(self)
+        for group in groups:
+            dataset = getattr(self, group)
+            valid_dims = set(dim).intersection(dataset.dims) if dim is not None else dim
+            dataset = dataset.unstack(dim=valid_dims)
+            setattr(out, group, dataset)
+        if inplace:
+            return None
+        else:
+            return out
+
+    def rename(self, name_dict=None, groups=None, filter_groups=None, inplace=False):
+        """Perform xarray renaming of variable and dimensions on all groups.
+
+        Loops groups to perform Dataset.rename(name_dict)
+        for every key in name_dict if key is a dimension/data_vars of the dataset.
+        The renaming is performed on all relevant groups (like
+        posterior, prior, sample stats) while non relevant groups like observed data are
+        omitted. See :meth:`xarray:xarray.Dataset.rename`
+
+        Parameters
+        ----------
+        name_dict: dict
+            Dictionary whose keys are current variable or dimension names
+            and whose values are the desired names.
+        groups: str or list of str, optional
+            Groups where the selection is to be applied. Can either be group names
+            or metagroup names.
+        filter_groups: {None, "like", "regex"}, optional, default=None
+            If `None` (default), interpret groups as the real group or metagroup names.
+            If "like", interpret groups as substrings of the real group or metagroup names.
+            If "regex", interpret groups as regular expressions on the real group or
+            metagroup names. A la `pandas.filter`.
+        inplace: bool, optional
+            If ``True``, modify the InferenceData object inplace,
+            otherwise, return the modified copy.
+
+
+        Returns
+        -------
+        InferenceData
+            A new InferenceData object by default.
+            When `inplace==True` perform renaming in-place and return `None`
+
+        """
+        groups = self._group_names(groups, filter_groups)
+        if "chain" in name_dict.keys() or "draw" in name_dict.keys():
+            raise KeyError("'chain' or 'draw' dimensions can't be renamed")
+        out = self if inplace else deepcopy(self)
+
+        for group in groups:
+            dataset = getattr(self, group)
+            expected_keys = list(dataset.data_vars) + list(dataset.dims)
+            valid_keys = set(name_dict.keys()).intersection(expected_keys)
+            dataset = dataset.rename({key: name_dict[key] for key in valid_keys})
+            setattr(out, group, dataset)
+        if inplace:
+            return None
+        else:
+            return out
+
+    def rename_vars(self, name_dict=None, groups=None, filter_groups=None, inplace=False):
+        """Perform xarray renaming of variable or coordinate names on all groups.
+
+        Loops groups to perform Dataset.rename_vars(name_dict)
+        for every key in name_dict if key is a variable or coordinate names of the dataset.
+        The renaming is performed on all relevant groups (like
+        posterior, prior, sample stats) while non relevant groups like observed data are
+        omitted. See :meth:`xarray:xarray.Dataset.rename_vars`
+
+        Parameters
+        ----------
+        name_dict: dict
+            Dictionary whose keys are current variable or coordinate names
+            and whose values are the desired names.
+        groups: str or list of str, optional
+            Groups where the selection is to be applied. Can either be group names
+            or metagroup names.
+        filter_groups: {None, "like", "regex"}, optional, default=None
+            If `None` (default), interpret groups as the real group or metagroup names.
+            If "like", interpret groups as substrings of the real group or metagroup names.
+            If "regex", interpret groups as regular expressions on the real group or
+            metagroup names. A la `pandas.filter`.
+        inplace: bool, optional
+            If ``True``, modify the InferenceData object inplace,
+            otherwise, return the modified copy.
+
+
+        Returns
+        -------
+        InferenceData
+            A new InferenceData object with renamed variables including coordinates by default.
+            When `inplace==True` perform renaming in-place and return `None`
+
+        """
+        groups = self._group_names(groups, filter_groups)
+
+        out = self if inplace else deepcopy(self)
+        for group in groups:
+            dataset = getattr(self, group)
+            valid_keys = set(name_dict.keys()).intersection(dataset.data_vars)
+            dataset = dataset.rename_vars({key: name_dict[key] for key in valid_keys})
+            setattr(out, group, dataset)
+        if inplace:
+            return None
+        else:
+            return out
+
+    def rename_dims(self, name_dict=None, groups=None, filter_groups=None, inplace=False):
+        """Perform xarray renaming of dimensions on all groups.
+
+        Loops groups to perform Dataset.rename_dims(name_dict)
+        for every key in name_dict if key is a dimension of the dataset.
+        The renaming is performed on all relevant groups (like
+        posterior, prior, sample stats) while non relevant groups like observed data are
+        omitted. See :meth:`xarray:xarray.Dataset.rename_dims`
+
+        Parameters
+        ----------
+        name_dict: dict
+            Dictionary whose keys are current dimension names and whose values are the desired
+            names.
+        groups: str or list of str, optional
+            Groups where the selection is to be applied. Can either be group names
+            or metagroup names.
+        filter_groups: {None, "like", "regex"}, optional, default=None
+            If `None` (default), interpret groups as the real group or metagroup names.
+            If "like", interpret groups as substrings of the real group or metagroup names.
+            If "regex", interpret groups as regular expressions on the real group or
+            metagroup names. A la `pandas.filter`.
+        inplace: bool, optional
+            If ``True``, modify the InferenceData object inplace,
+            otherwise, return the modified copy.
+
+
+        Returns
+        -------
+        InferenceData
+            A new InferenceData object with renamed dimension by default.
+            When `inplace==True` perform renaming in-place and return `None`
+
+        """
+        groups = self._group_names(groups, filter_groups)
+        if "chain" in name_dict.keys() or "draw" in name_dict.keys():
+            raise KeyError("'chain' or 'draw' dimensions can't be renamed")
+
+        out = self if inplace else deepcopy(self)
+        for group in groups:
+            dataset = getattr(self, group)
+            valid_keys = set(name_dict.keys()).intersection(dataset.dims)
+            dataset = dataset.rename_dims({key: name_dict[key] for key in valid_keys})
+            setattr(out, group, dataset)
+        if inplace:
+            return None
+        else:
+            return out
+
+    def add_groups(self, group_dict=None, coords=None, dims=None, **kwargs):
+        """Add new groups to InferenceData object.
+
+        Parameters
+        ----------
+        group_dict: dict of {str : dict or xarray.Dataset}, optional
+            Groups to be added
+        coords : dict[str] -> ndarray
+            Coordinates for the dataset
+        dims : dict[str] -> list[str]
+            Dimensions of each variable. The keys are variable names, values are lists of
+            coordinates.
+        **kwargs: mapping
+            The keyword arguments form of group_dict. One of group_dict or kwargs must be provided.
+
+        See Also
+        --------
+        extend : Extend InferenceData with groups from another InferenceData.
+        concat : Concatenate InferenceData objects.
+        """
+        group_dict = either_dict_or_kwargs(group_dict, kwargs, "add_groups")
+        if not group_dict:
+            raise ValueError("One of group_dict or kwargs must be provided.")
+        repeated_groups = [group for group in group_dict.keys() if group in self._groups]
+        if repeated_groups:
+            raise ValueError("{} group(s) already exists.".format(repeated_groups))
+        for group, dataset in group_dict.items():
+            if group not in SUPPORTED_GROUPS_ALL:
+                warnings.warn(
+                    "The group {} is not defined in the InferenceData scheme".format(group),
+                    UserWarning,
+                )
+            if dataset is None:
+                continue
+            elif isinstance(dataset, dict):
+                if (
+                    group in ("observed_data", "constant_data", "predictions_constant_data")
+                    or group not in SUPPORTED_GROUPS_ALL
+                ):
+                    warnings.warn(
+                        "the default dims 'chain' and 'draw' will be added automatically",
+                        UserWarning,
+                    )
+                dataset = dict_to_dataset(dataset, coords=coords, dims=dims)
+            elif isinstance(dataset, xr.DataArray):
+                if dataset.name is None:
+                    dataset.name = "x"
+                dataset = dataset.to_dataset()
+            elif not isinstance(dataset, xr.Dataset):
+                raise ValueError(
+                    "Arguments to add_groups() must be xr.Dataset, xr.Dataarray or dicts\
+                    (argument '{}' was type '{}')".format(
+                        group, type(dataset)
+                    )
+                )
+            if dataset:
+                setattr(self, group, dataset)
+                if group.startswith(WARMUP_TAG):
+                    self._groups_warmup.append(group)
+                else:
+                    self._groups.append(group)
+
+    def extend(self, other, join="left"):
+        """Extend InferenceData with groups from another InferenceData.
+
+        Parameters
+        ----------
+        other : InferenceData
+            InferenceData to be added
+        join : {'left', 'right'}, default 'left'
+            Defines how the two decide which group to keep when the same group is
+            present in both objects. 'left' will discard the group in ``other`` whereas 'right'
+            will keep the group in ``other`` and discard the one in ``self``.
+
+        See Also
+        --------
+        add_groups : Add new groups to InferenceData object.
+        concat : Concatenate InferenceData objects.
+
+        """
+        if not isinstance(other, InferenceData):
+            raise ValueError("Extending is possible between two InferenceData objects only.")
+        if join not in ("left", "right"):
+            raise ValueError("join must be either 'left' or 'right', found {}".format(join))
+        for group in other._groups_all:  # pylint: disable=protected-access
+            if hasattr(self, group):
+                if join == "left":
+                    continue
+            if group not in SUPPORTED_GROUPS_ALL:
+                warnings.warn(
+                    "{} group is not defined in the InferenceData scheme".format(group), UserWarning
+                )
+            dataset = getattr(other, group)
+            setattr(self, group, dataset)
+            if group.startswith(WARMUP_TAG):
+                self._groups_warmup.append(group)
+            else:
+                self._groups.append(group)
+
+    set_index = _extend_xr_method(xr.Dataset.set_index)
+    get_index = _extend_xr_method(xr.Dataset.get_index)
+    reset_index = _extend_xr_method(xr.Dataset.reset_index)
+    set_coords = _extend_xr_method(xr.Dataset.set_coords)
+    reset_coords = _extend_xr_method(xr.Dataset.reset_coords)
+    assign = _extend_xr_method(xr.Dataset.assign)
+    assign_coords = _extend_xr_method(xr.Dataset.assign_coords)
+    sortby = _extend_xr_method(xr.Dataset.sortby)
+    chunk = _extend_xr_method(xr.Dataset.chunk)
+    unify_chunks = _extend_xr_method(xr.Dataset.unify_chunks)
+    load = _extend_xr_method(xr.Dataset.load)
+    compute = _extend_xr_method(xr.Dataset.compute)
+    persist = _extend_xr_method(xr.Dataset.persist)
+
+    mean = _extend_xr_method(xr.Dataset.mean)
+    median = _extend_xr_method(xr.Dataset.median)
+    min = _extend_xr_method(xr.Dataset.min)
+    max = _extend_xr_method(xr.Dataset.max)
+    cumsum = _extend_xr_method(xr.Dataset.cumsum)
+    sum = _extend_xr_method(xr.Dataset.sum)
+    quantile = _extend_xr_method(xr.Dataset.quantile)
+
     def _group_names(self, groups, filter_groups=None):
         """Handle expansion of group names input across arviz.
 
@@ -368,7 +913,7 @@ class InferenceData:
             group_names = _subset_list(sel_groups, all_groups, filter_items=filter_groups)
         except KeyError as err:
             msg = " ".join(("groups:", f"{err}", "in InferenceData"))
-            raise KeyError(msg)
+            raise KeyError(msg) from err
         return group_names
 
     def map(self, fun, groups=None, filter_groups=None, inplace=False, args=None, **kwargs):
@@ -422,8 +967,8 @@ class InferenceData:
 
             In [1]: idata = az.load_arviz_data("radon")
                ...: idata = idata.map(
-               ...:     lambda ds: ds.rename({"gamma_dim_0": "uranium_coefs"}).assign(
-               ...:         uranium_coefs=["intercept", "u_slope", "xbar_slope"]
+               ...:     lambda ds: ds.rename({"g_coef": "uranium_coefs"}).assign(
+               ...:         uranium_coefs=["intercept", "u_slope"]
                ...:     ),
                ...:     groups=["posterior", "prior"]
                ...: )
@@ -561,6 +1106,11 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
         A new InferenceData object by default.
         When `inplace==True` merge args to first arg and return `None`
 
+    See Also
+    --------
+    add_groups : Add new groups to InferenceData object.
+    extend : Extend InferenceData with groups from another InferenceData.
+
     Examples
     --------
     Use ``concat`` method to concatenate InferenceData objects. This will concatenates over
@@ -652,8 +1202,9 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
                 if group in args_groups or group in arg0_groups:
                     msg = (
                         "Concatenating overlapping groups is not supported unless `dim` is defined."
+                        " Valid dimensions are `chain` and `draw`. Alternatively, use extend to"
+                        " combine InferenceData with overlapping groups"
                     )
-                    msg += " Valid dimensions are `chain` and `draw`."
                     raise TypeError(msg)
                 group_data = getattr(arg, group)
                 args_groups[group] = deepcopy(group_data) if copy else group_data
@@ -740,7 +1291,7 @@ def concat(*args, dim=None, copy=True, inplace=False, reset_dim=True):
                             raise TypeError(msg)
 
                     # xr.concat
-                    concatenated_group = xr.concat((group_data, group0_data), dim=dim)
+                    concatenated_group = xr.concat((group0_data, group_data), dim=dim)
                     if reset_dim:
                         concatenated_group[dim] = range(concatenated_group[dim].size)
 
