@@ -1,11 +1,12 @@
 """NumPyro-specific conversion code."""
 import logging
+
 import numpy as np
 import xarray as xr
 
-from .inference_data import InferenceData
-from .base import requires, dict_to_dataset, generate_dims_coords, make_attrs
 from .. import utils
+from .base import dict_to_dataset, generate_dims_coords, make_attrs, requires
+from .inference_data import InferenceData
 
 _log = logging.getLogger(__name__)
 
