@@ -1,13 +1,14 @@
 """Pyro-specific conversion code."""
 import logging
 import warnings
-import numpy as np
-from packaging import version
-import xarray as xr
 
-from .inference_data import InferenceData
-from .base import requires, dict_to_dataset, generate_dims_coords, make_attrs
+import numpy as np
+import xarray as xr
+from packaging import version
+
 from .. import utils
+from .base import dict_to_dataset, generate_dims_coords, make_attrs, requires
+from .inference_data import InferenceData
 
 _log = logging.getLogger(__name__)
 
