@@ -1,14 +1,8 @@
 """Autocorrelation plot of data."""
 from ..data import convert_to_dataset
-from .plot_utils import (
-    _scale_fig_size,
-    default_grid,
-    xarray_var_iter,
-    filter_plotters_list,
-    get_plotting_function,
-)
 from ..rcparams import rcParams
 from ..utils import _var_names
+from .plot_utils import default_grid, filter_plotters_list, get_plotting_function, xarray_var_iter
 
 
 def plot_autocorr(
@@ -117,10 +111,6 @@ def plot_autocorr(
     )
     rows, cols = default_grid(len(plotters))
 
-    figsize, _, titlesize, xt_labelsize, linewidth, _ = _scale_fig_size(
-        figsize, textsize, rows, cols
-    )
-
     autocorr_plot_args = dict(
         axes=ax,
         plotters=plotters,
@@ -129,9 +119,7 @@ def plot_autocorr(
         rows=rows,
         cols=cols,
         combined=combined,
-        linewidth=linewidth,
-        xt_labelsize=xt_labelsize,
-        titlesize=titlesize,
+        textsize=textsize,
         backend_kwargs=backend_kwargs,
         show=show,
     )
@@ -141,10 +129,6 @@ def plot_autocorr(
     backend = backend.lower()
 
     if backend == "bokeh":
-
-        autocorr_plot_args.pop("xt_labelsize")
-        autocorr_plot_args.pop("titlesize")
-        autocorr_plot_args["line_width"] = autocorr_plot_args.pop("linewidth")
         autocorr_plot_args.update(backend_config=backend_config)
 
     # TODO: Add backend kwargs
