@@ -1,9 +1,9 @@
 """Bokeh Compareplot."""
-import bokeh.plotting as bkp
 from bokeh.models import Span
 
-from . import backend_kwarg_defaults
+from ...plot_utils import _scale_fig_size
 from .. import show_layout
+from . import backend_kwarg_defaults, create_axes_grid
 
 
 def plot_compare(
@@ -15,8 +15,8 @@ def plot_compare(
     insample_dev,
     yticks_pos,
     yticks_labels,
-    line_width,
     plot_kwargs,
+    textsize,
     information_criterion,
     step,
     backend_kwargs,
@@ -27,15 +27,19 @@ def plot_compare(
         backend_kwargs = {}
 
     backend_kwargs = {
-        **backend_kwarg_defaults(("dpi", "plot.bokeh.figure.dpi"),),
+        **backend_kwarg_defaults(),
         **backend_kwargs,
     }
-    dpi = backend_kwargs.pop("dpi")
+
+    figsize, _, _, _, line_width, _ = _scale_fig_size(figsize, textsize, 1, 1)
 
     if ax is None:
-        backend_kwargs.setdefault("width", int(figsize[0] * dpi))
-        backend_kwargs.setdefault("height", int(figsize[1] * dpi))
-        ax = bkp.figure(**backend_kwargs)
+        ax = create_axes_grid(
+            1,
+            figsize=figsize,
+            squeeze=True,
+            backend_kwargs=backend_kwargs,
+        )
 
     yticks_pos = list(yticks_pos)
 
