@@ -1,12 +1,12 @@
 """Bokeh Distplot."""
-import bokeh.plotting as bkp
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
-from . import backend_kwarg_defaults
-from .. import show_layout
+from ....stats.density_utils import get_bins, histogram
 from ...kdeplot import plot_kde
-from ....numeric_utils import get_bins
+from ...plot_utils import _scale_fig_size, set_bokeh_circular_ticks_labels, vectorized_to_hex
+from .. import show_layout
+from . import backend_kwarg_defaults, create_axes_grid
 
 
 def plot_dist(
@@ -19,9 +19,12 @@ def plot_dist(
     rotated,
     rug,
     bw,
+    circular,
     quantiles,
     contour,
     fill_last,
+    figsize,
+    textsize,
     plot_kwargs,
     fill_kwargs,
     rug_kwargs,
@@ -29,10 +32,10 @@ def plot_dist(
     contourf_kwargs,
     pcolormesh_kwargs,
     hist_kwargs,
+    is_circular,
     ax,
     backend_kwargs,
     show,
-    **kwargs  # pylint: disable=unused-argument
 ):
     """Bokeh distplot."""
     if backend_kwargs is None:
@@ -42,15 +45,40 @@ def plot_dist(
         **backend_kwarg_defaults(),
         **backend_kwargs,
     }
+
+    figsize, *_ = _scale_fig_size(figsize, textsize)
+
+    color = vectorized_to_hex(color)
+
+    hist_kwargs = {} if hist_kwargs is None else hist_kwargs
+    if kind == "hist":
+        hist_kwargs.setdefault("cumulative", cumulative)
+        hist_kwargs.setdefault("fill_color", color)
+        hist_kwargs.setdefault("line_color", color)
+        hist_kwargs.setdefault("line_alpha", 0)
+        if label is not None:
+            hist_kwargs.setdefault("legend_label", str(label))
+
     if ax is None:
-        ax = bkp.figure(**backend_kwargs)
+        ax = create_axes_grid(
+            1,
+            figsize=figsize,
+            squeeze=True,
+            polar=is_circular,
+            backend_kwargs=backend_kwargs,
+        )
 
     if kind == "auto":
         kind = "hist" if values.dtype.kind == "i" else "kde"
 
     if kind == "hist":
         _histplot_bokeh_op(
-            values=values, values2=values2, rotated=rotated, ax=ax, hist_kwargs=hist_kwargs
+            values=values,
+            values2=values2,
+            rotated=rotated,
+            ax=ax,
+            hist_kwargs=hist_kwargs,
+            is_circular=is_circular,
         )
     elif kind == "kde":
         if plot_kwargs is None:
@@ -67,6 +95,7 @@ def plot_dist(
             rug=rug,
             label=label,
             bw=bw,
+            circular=circular,
             quantiles=quantiles,
             rotated=rotated,
             contour=contour,
@@ -91,36 +120,64 @@ def plot_dist(
     return ax
 
 
-def _histplot_bokeh_op(values, values2, rotated, ax, hist_kwargs):
+def _histplot_bokeh_op(values, values2, rotated, ax, hist_kwargs, is_circular):
     """Add a histogram for the data to the axes."""
     if values2 is not None:
         raise NotImplementedError("Insert hexbin plot here")
 
-    legend_label = hist_kwargs.pop("label", None)
-    if legend_label:
-        hist_kwargs["legend_label"] = legend_label
-
     color = hist_kwargs.pop("color", False)
     if color:
         hist_kwargs["fill_color"] = color
         hist_kwargs["line_color"] = color
 
-    # remove defaults for mpl
-    hist_kwargs.pop("rwidth", None)
-    hist_kwargs.pop("align", None)
-    hist_kwargs.pop("density", None)
-    hist_kwargs.pop("orientation", None)
-
     bins = hist_kwargs.pop("bins", None)
     if bins is None:
         bins = get_bins(values)
-    density = hist_kwargs.pop("density", True)
-    hist, edges = np.histogram(np.asarray(values).flatten(), density=density, bins=bins)
+    hist, hist_dens, edges = histogram(np.asarray(values).flatten(), bins=bins)
+    if hist_kwargs.pop("density", True):
+        hist = hist_dens
     if hist_kwargs.pop("cumulative", False):
         hist = np.cumsum(hist)
         hist /= hist[-1]
-    if rotated:
-        ax.quad(top=edges[:-1], bottom=edges[1:], left=0, right=hist, **hist_kwargs)
+
+    if is_circular:
+
+        if is_circular == "degrees":
+            edges = np.deg2rad(edges)
+            labels = ["0°", "45°", "90°", "135°", "180°", "225°", "270°", "315°"]
+        else:
+
+            labels = [
+                r"0",
+                r"π/4",
+                r"π/2",
+                r"3π/4",
+                r"π",
+                r"5π/4",
+                r"3π/2",
+                r"7π/4",
+            ]
+
+        delta = np.mean(np.diff(edges) / 2)
+
+        ax.annular_wedge(
+            x=0,
+            y=0,
+            inner_radius=0,
+            outer_radius=hist,
+            start_angle=edges[1:] - delta,
+            end_angle=edges[:-1] - delta,
+            direction="clock",
+            **hist_kwargs,
+        )
+
+        ax = set_bokeh_circular_ticks_labels(ax, hist, labels)
+
     else:
-        ax.quad(top=hist, bottom=0, left=edges[:-1], right=edges[1:], **hist_kwargs)
+
+        if rotated:
+            ax.quad(top=edges[:-1], bottom=edges[1:], left=0, right=hist, **hist_kwargs)
+        else:
+            ax.quad(top=hist, bottom=0, left=edges[:-1], right=edges[1:], **hist_kwargs)
+
     return ax
