@@ -1,23 +1,23 @@
 # pylint: disable=all
 """Bokeh forestplot."""
-from collections import defaultdict, OrderedDict
+from collections import OrderedDict, defaultdict
 from itertools import cycle, tee
 
 import bokeh.plotting as bkp
+import matplotlib.pyplot as plt
+import numpy as np
 from bokeh.models import Band, ColumnDataSource, DataRange1d
 from bokeh.models.annotations import Title
 from bokeh.models.tickers import FixedTicker
-import matplotlib.pyplot as plt
-import numpy as np
 
-from . import backend_kwarg_defaults
-from .. import show_layout
-from ...plot_utils import _scale_fig_size, xarray_var_iter, make_label
 from ....rcparams import rcParams
 from ....stats import hdi
+from ....stats.density_utils import get_bins, histogram, kde
 from ....stats.diagnostics import _ess, _rhat
-from ....numeric_utils import _fast_kde, histogram, get_bins
 from ....utils import conditional_jit
+from ...plot_utils import _scale_fig_size, make_label, xarray_var_iter
+from .. import show_layout
+from . import backend_kwarg_defaults
 
 
 def pairwise(iterable):
@@ -46,6 +46,7 @@ def plot_forest(
     ridgeplot_overlap,
     ridgeplot_alpha,
     ridgeplot_kind,
+    ridgeplot_truncate,
     ridgeplot_quantiles,
     textsize,
     ess,
@@ -88,7 +89,9 @@ def plot_forest(
         backend_kwargs = {}
 
     backend_kwargs = {
-        **backend_kwarg_defaults(("dpi", "plot.bokeh.figure.dpi"),),
+        **backend_kwarg_defaults(
+            ("dpi", "plot.bokeh.figure.dpi"),
+        ),
         **backend_kwargs,
     }
     dpi = backend_kwargs.pop("dpi")
@@ -103,10 +106,12 @@ def plot_forest(
                 "height", int(figsize[1] * (width_r / sum(width_ratios)) * dpi * 1.25)
             )
             if i == 0:
-                ax = bkp.figure(**backend_kwargs,)
-                _y_range = ax.y_range
+                ax = bkp.figure(
+                    **backend_kwargs_i,
+                )
+                backend_kwargs_i.setdefault("y_range", ax.y_range)
             else:
-                ax = bkp.figure(y_range=_y_range, **backend_kwargs,)
+                ax = bkp.figure(**backend_kwargs_i)
             axes.append(ax)
     else:
         axes = ax
@@ -115,14 +120,22 @@ def plot_forest(
 
     if kind == "forestplot":
         plot_handler.forestplot(
-            hdi_prob, quartiles, linewidth, markersize, axes[0, 0], rope,
+            hdi_prob,
+            quartiles,
+            linewidth,
+            markersize,
+            axes[0, 0],
+            rope,
         )
     elif kind == "ridgeplot":
         plot_handler.ridgeplot(
+            hdi_prob,
             ridgeplot_overlap,
             linewidth,
+            markersize,
             ridgeplot_alpha,
             ridgeplot_kind,
+            ridgeplot_truncate,
             ridgeplot_quantiles,
             axes[0, 0],
         )
@@ -253,44 +266,69 @@ class PlotHandler:
 
         return label_idxs()
 
-    def display_multiple_ropes(self, rope, ax, y, linewidth, rope_var):
+    def display_multiple_ropes(self, rope, ax, y, linewidth, var_name, selection):
         """Display ROPE when more than one interval is provided."""
-        vals = dict(rope[rope_var][0])["rope"]
-        ax.line(
-            vals,
-            (y + 0.05, y + 0.05),
-            line_width=linewidth * 2,
-            color=[
-                color
-                for _, color in zip(
-                    range(3), cycle(plt.rcParams["axes.prop_cycle"].by_key()["color"])
+        for sel in rope.get(var_name, []):
+            # pylint: disable=line-too-long
+            if all(k in selection and selection[k] == v for k, v in sel.items() if k != "rope"):
+                vals = sel["rope"]
+                ax.line(
+                    vals,
+                    (y + 0.05, y + 0.05),
+                    line_width=linewidth * 2,
+                    color=[
+                        color
+                        for _, color in zip(
+                            range(3), cycle(plt.rcParams["axes.prop_cycle"].by_key()["color"])
+                        )
+                    ][2],
+                    line_alpha=0.7,
                 )
-            ][2],
-            line_alpha=0.7,
-        )
-        return ax
+                return ax
 
-    def ridgeplot(self, mult, linewidth, alpha, ridgeplot_kind, ridgeplot_quantiles, ax):
+    def ridgeplot(
+        self,
+        hdi_prob,
+        mult,
+        linewidth,
+        markersize,
+        alpha,
+        ridgeplot_kind,
+        ridgeplot_truncate,
+        ridgeplot_quantiles,
+        ax,
+    ):
         """Draw ridgeplot for each plotter.
 
         Parameters
         ----------
+        hdi_prob : float
+            Probability for the highest density interval.
         mult : float
             How much to multiply height by. Set this to greater than 1 to have some overlap.
         linewidth : float
             Width of line on border of ridges
+        markersize : float
+            Size of marker in center of forestplot line
         alpha : float
             Transparency of ridges
-        kind : string
+        ridgeplot_kind : string
             By default ("auto") continuous variables are plotted using KDEs and discrete ones using
             histograms. To override this use "hist" to plot histograms and "density" for KDEs
+        ridgeplot_truncate: bool
+            Whether to truncate densities according to the value of hdi_prop. Defaults to True
+        ridgeplot_quantiles: list
+            Quantiles in ascending order used to segment the KDE. Use [.25, .5, .75] for quartiles.
+            Defaults to None.
         ax : Axes
             Axes to draw on
         """
         if alpha is None:
             alpha = 1.0
         for plotter in list(self.plotters.values())[::-1]:
-            for x, y_min, y_max, y_q, color in list(plotter.ridgeplot(mult, ridgeplot_kind))[::-1]:
+            for x, y_min, y_max, hdi_, y_q, color in plotter.ridgeplot(
+                hdi_prob, mult, ridgeplot_kind
+            ):
                 if alpha == 0:
                     border = color
                     facecolor = None
@@ -298,50 +336,66 @@ class PlotHandler:
                     border = "black"
                     facecolor = color
                 if x.dtype.kind == "i":
+                    if ridgeplot_truncate:
+                        y_max = y_max[(x >= hdi_[0]) & (x <= hdi_[1])]
+                        x = x[(x >= hdi_[0]) & (x <= hdi_[1])]
+                    else:
+                        facecolor = color
+                        alpha = [alpha if ci else 0 for ci in ((x >= hdi_[0]) & (x <= hdi_[1]))]
+                    y_min = np.ones_like(x) * y_min
                     ax.vbar(
                         x=x,
                         top=y_max - y_min,
                         bottom=y_min,
+                        width=0.9,
+                        line_color=border,
+                        color=facecolor,
                         fill_alpha=alpha,
-                        fill_color=facecolor,
                     )
                 else:
-                    if ridgeplot_quantiles is None:
-                        patch = ax.patch(
-                            np.concatenate([x, x[::-1]]),
-                            np.concatenate([y_min, y_max[::-1]]),
-                            fill_color=color,
-                            fill_alpha=alpha,
+                    tr_x = x[(x >= hdi_[0]) & (x <= hdi_[1])]
+                    tr_y_min = np.ones_like(tr_x) * y_min
+                    tr_y_max = y_max[(x >= hdi_[0]) & (x <= hdi_[1])]
+                    y_min = np.ones_like(x) * y_min
+                    patch = ax.patch(
+                        np.concatenate([tr_x, tr_x[::-1]]),
+                        np.concatenate([tr_y_min, tr_y_max[::-1]]),
+                        fill_color=color,
+                        fill_alpha=alpha,
+                        line_width=0,
+                    )
+                    patch.level = "overlay"
+                    if ridgeplot_truncate:
+                        ax.line(
+                            x, y_max, line_dash="solid", line_width=linewidth, line_color=border
+                        )
+                        ax.line(
+                            x, y_min, line_dash="solid", line_width=linewidth, line_color=border
+                        )
+                    else:
+                        ax.line(
+                            tr_x,
+                            tr_y_max,
                             line_dash="solid",
                             line_width=linewidth,
                             line_color=border,
                         )
-                        patch.level = "overlay"
-                    else:
-                        quantiles = sorted(np.clip(ridgeplot_quantiles, 0, 1))
-                        if quantiles[0] != 0:
-                            quantiles = [0] + quantiles
-                        if quantiles[-1] != 1:
-                            quantiles = quantiles + [1]
-
-                        for quant_0, quant_1 in zip(quantiles[:-1], quantiles[1:]):
-                            idx = (y_q > quant_0) & (y_q < quant_1)
-                            if idx.sum():
-                                patch_x = np.concatenate(
-                                    (x[idx], [x[idx][-1]], x[idx][::-1], [x[idx][0]])
-                                )
-                                patch_y = np.concatenate(
-                                    (
-                                        y_min[idx],
-                                        [y_min[idx][-1]],
-                                        y_max[idx][::-1],
-                                        [y_max[idx][0]],
-                                    )
-                                )
-                                patch = ax.patch(
-                                    patch_x, patch_y, fill_color=color, fill_alpha=alpha,
-                                )
-                            patch.level = "overlay"
+                        ax.line(
+                            tr_x,
+                            tr_y_min,
+                            line_dash="solid",
+                            line_width=linewidth,
+                            line_color=border,
+                        )
+                if ridgeplot_quantiles is not None:
+                    quantiles = [x[np.sum(y_q < quant)] for quant in ridgeplot_quantiles]
+                    ax.diamond(
+                        quantiles,
+                        np.ones_like(quantiles) * y_min[0],
+                        line_color="black",
+                        fill_color="black",
+                        size=markersize,
+                    )
 
         return ax
 
@@ -351,7 +405,7 @@ class PlotHandler:
         Parameters
         ----------
         hdi_prob : float
-            How wide each line should be
+            Probability for the highest density interval. Width of each line.
         quartiles : bool
             Whether to mark quartiles
         linewidth : float
@@ -401,9 +455,9 @@ class PlotHandler:
             qlist = [endpoint, 50, 100 - endpoint]
 
         for plotter in self.plotters.values():
-            for y, rope_var, values, color in plotter.treeplot(qlist, hdi_prob):
+            for y, selection, values, color in plotter.treeplot(qlist, hdi_prob):
                 if isinstance(rope, dict):
-                    self.display_multiple_ropes(rope, ax, y, linewidth, rope_var)
+                    self.display_multiple_ropes(rope, ax, y, linewidth, plotter.var_name, selection)
 
                 mid = len(values) // 2
                 param_iter = zip(
@@ -414,7 +468,10 @@ class PlotHandler:
                         [values[j], values[-(j + 1)]], [y, y], line_width=width, line_color=color
                     )
                 ax.circle(
-                    x=values[mid], y=y, size=markersize * 0.75, fill_color=color,
+                    x=values[mid],
+                    y=y,
+                    size=markersize * 0.75,
+                    fill_color=color,
                 )
         _title = Title()
         _title.text = "{:.1%} HDI".format(hdi_prob)
@@ -429,7 +486,11 @@ class PlotHandler:
             for y, ess, color in plotter.ess():
                 if ess is not None:
                     ax.circle(
-                        x=ess, y=y, fill_color=color, size=markersize, line_color="black",
+                        x=ess,
+                        y=y,
+                        fill_color=color,
+                        size=markersize,
+                        line_color="black",
                     )
                 if ess > max_ess:
                     max_ess = ess
@@ -502,6 +563,7 @@ class VarHandler:
             skip_dims = set()
 
         label_dict = OrderedDict()
+        selection_list = []
         for name, grouped_datum in zip(self.model_names, grouped_data):
             for _, sub_data in grouped_datum:
                 datum_iter = xarray_var_iter(
@@ -511,6 +573,7 @@ class VarHandler:
                     reverse_selections=True,
                 )
                 for _, selection, values in datum_iter:
+                    selection_list.append(selection)
                     label = make_label(self.var_name, selection, position="beside")
                     if label not in label_dict:
                         label_dict[label] = OrderedDict()
@@ -519,14 +582,16 @@ class VarHandler:
                     label_dict[label][name].append(values)
 
         y = self.y_start
-        for label, model_data in label_dict.items():
+        for idx, (label, model_data) in enumerate(label_dict.items()):
             for model_name, value_list in model_data.items():
                 if model_name:
                     row_label = "{}: {}".format(model_name, label)
                 else:
                     row_label = label
                 for values in value_list:
-                    yield y, row_label, label, values, self.model_color[model_name]
+                    yield y, row_label, label, selection_list[idx], values, self.model_color[
+                        model_name
+                    ]
                     y += self.chain_offset
                 y += self.var_offset
             y += self.group_offset
@@ -534,7 +599,7 @@ class VarHandler:
     def labels_ticks_and_vals(self):
         """Get labels, ticks, values, and colors for the variable."""
         y_ticks = defaultdict(list)
-        for y, label, _, vals, color in self.iterator():
+        for y, label, _, _, vals, color in self.iterator():
             y_ticks[label].append((y, vals, color))
         labels, ticks, vals, colors = [], [], [], []
         for label, data in y_ticks.items():
@@ -546,20 +611,26 @@ class VarHandler:
 
     def treeplot(self, qlist, hdi_prob):
         """Get data for each treeplot for the variable."""
-        for y, _, label, values, color in self.iterator():
+        for y, _, _, selection, values, color in self.iterator():
             ntiles = np.percentile(values.flatten(), qlist)
             ntiles[0], ntiles[-1] = hdi(values.flatten(), hdi_prob, multimodal=False)
-            yield y, label, ntiles, color
+            yield y, selection, ntiles, color
 
-    def ridgeplot(self, mult, ridgeplot_kind):
+    def ridgeplot(self, hdi_prob, mult, ridgeplot_kind):
         """Get data for each ridgeplot for the variable."""
-        xvals, yvals, pdfs, pdfs_q, colors = [], [], [], [], []
+        xvals, hdi_vals, yvals, pdfs, pdfs_q, colors = [], [], [], [], [], []
+
         for y, *_, values, color in self.iterator():
             yvals.append(y)
             colors.append(color)
             values = values.flatten()
             values = values[np.isfinite(values)]
 
+            if hdi_prob != 1:
+                hdi_ = hdi(values, hdi_prob, multimodal=False)
+            else:
+                hdi_ = min(values), max(values)
+
             if ridgeplot_kind == "auto":
                 kind = "hist" if np.all(np.mod(values, 1) == 0) else "density"
             else:
@@ -570,18 +641,18 @@ class VarHandler:
                 _, density, x = histogram(values, bins=bins)
                 x = x[:-1]
             elif kind == "density":
-                density, lower, upper = _fast_kde(values)
-                density_q = density.cumsum() / density.sum()
-                x = np.linspace(lower, upper, len(density))
+                x, density = kde(values)
+
+            density_q = density.cumsum() / density.sum()
 
             xvals.append(x)
             pdfs.append(density)
-            pdfs_q.append((density_q))
+            pdfs_q.append(density_q)
+            hdi_vals.append(hdi_)
 
         scaling = max(np.max(j) for j in pdfs)
-        for y, x, pdf, pdf_q, color in zip(yvals, xvals, pdfs, pdfs_q, colors):
-            y = y * np.ones_like(x)
-            yield x, y, mult * pdf / scaling + y, pdf_q, color
+        for y, x, hdi_val, pdf, pdf_q, color in zip(yvals, xvals, hdi_vals, pdfs, pdfs_q, colors):
+            yield x, y, mult * pdf / scaling + y, hdi_val, pdf_q, color
 
     def ess(self):
         """Get effective n data for the variable."""
