@@ -1,10 +1,9 @@
 """Matplotlib kdeplot."""
-import warnings
-from matplotlib import pyplot as plt
 import numpy as np
+from matplotlib import pyplot as plt
 
-from . import backend_show
-from ...plot_utils import _scale_fig_size, matplotlib_kwarg_dealiaser
+from ...plot_utils import _scale_fig_size
+from . import backend_kwarg_defaults, backend_show, create_axes_grid, matplotlib_kwarg_dealiaser
 
 
 def plot_kde(
@@ -25,6 +24,7 @@ def plot_kde(
     rotated,
     contour,
     fill_last,
+    figsize,
     textsize,
     plot_kwargs,
     fill_kwargs,
@@ -32,25 +32,34 @@ def plot_kde(
     contour_kwargs,
     contourf_kwargs,
     pcolormesh_kwargs,
+    is_circular,
     ax,
     legend,
     backend_kwargs,
     show,
+    return_glyph,  # pylint: disable=unused-argument
 ):
     """Matplotlib kde plot."""
-    if backend_kwargs is not None:
-        warnings.warn(
-            (
-                "Argument backend_kwargs has not effect in matplotlib.plot_kde"
-                "Supplied value won't be used"
-            )
-        )
+    if backend_kwargs is None:
+        backend_kwargs = {}
+
+    backend_kwargs = {
+        **backend_kwarg_defaults(),
+        **backend_kwargs,
+    }
+
+    figsize, *_, xt_labelsize, linewidth, markersize = _scale_fig_size(figsize, textsize)
+
+    backend_kwargs.setdefault("figsize", figsize)
+    backend_kwargs["squeeze"] = True
+    backend_kwargs.setdefault("subplot_kw", {})
+    backend_kwargs["subplot_kw"].setdefault("polar", is_circular)
+
     if ax is None:
-        ax = plt.gca()
-
-    figsize = ax.get_figure().get_size_inches()
-
-    figsize, *_, xt_labelsize, linewidth, markersize = _scale_fig_size(figsize, textsize, 1, 1)
+        _, ax = create_axes_grid(
+            1,
+            backend_kwargs=backend_kwargs,
+        )
 
     if values2 is None:
         plot_kwargs = matplotlib_kwarg_dealiaser(plot_kwargs, "plot")
@@ -70,13 +79,29 @@ def plot_kde(
         plot_kwargs.setdefault("linewidth", linewidth)
         rug_kwargs.setdefault("markersize", 2 * markersize)
 
-        figsize = ax.get_figure().get_size_inches()
-
-        figsize, *_, xt_labelsize, linewidth, markersize = _scale_fig_size(figsize, textsize, 1, 1)
-
         rug_space = max(density) * rug_kwargs.pop("space")
 
-        x = np.linspace(lower, upper, len(density))
+        if is_circular:
+
+            if is_circular == "radians":
+                labels = [
+                    r"0",
+                    r"π/4",
+                    r"π/2",
+                    r"3π/4",
+                    r"π",
+                    r"5π/4",
+                    r"3π/2",
+                    r"7π/4",
+                ]
+
+                ax.set_xticklabels(labels)
+
+            x = np.linspace(-np.pi, np.pi, len(density))
+            ax.set_yticklabels([])
+
+        else:
+            x = np.linspace(lower, upper, len(density))
 
         fill_func = ax.fill_between
         fill_x, fill_y = x, density
@@ -123,9 +148,6 @@ def plot_kde(
         contourf_kwargs = matplotlib_kwarg_dealiaser(contourf_kwargs, "contour")
         pcolormesh_kwargs = matplotlib_kwarg_dealiaser(pcolormesh_kwargs, "pcolormesh")
 
-        # gridsize = (128, 128) if contour else (256, 256)
-
-        # density, xmin, xmax, ymin, ymax = _fast_kde_2d(values, values2, gridsize=gridsize)
         g_s = complex(gridsize[0])
         x_x, y_y = np.mgrid[xmin:xmax:g_s, ymin:ymax:g_s]
 
