@@ -1,20 +1,20 @@
 """Matplotlib Plot posterior densities."""
-from typing import Optional
 from numbers import Number
+
 import matplotlib.pyplot as plt
 import numpy as np
 
-from . import backend_show
 from ....stats import hdi
+from ....stats.density_utils import get_bins
 from ...kdeplot import plot_kde
 from ...plot_utils import (
-    make_label,
-    _create_axes_grid,
-    format_sig_figs,
-    round_num,
+    _scale_fig_size,
     calculate_point_estimate,
+    format_sig_figs,
+    make_label,
+    round_num,
 )
-from ....numeric_utils import get_bins
+from . import backend_kwarg_defaults, backend_show, create_axes_grid, matplotlib_kwarg_dealiaser
 
 
 def plot_posterior(
@@ -25,29 +25,46 @@ def plot_posterior(
     figsize,
     plotters,
     bw,
+    circular,
     bins,
     kind,
     point_estimate,
     round_to,
     hdi_prob,
     multimodal,
+    textsize,
     ref_val,
     rope,
-    ax_labelsize,
-    xt_labelsize,
     kwargs,
-    titlesize,
     backend_kwargs,
     show,
 ):
     """Matplotlib posterior plot."""
+    if backend_kwargs is None:
+        backend_kwargs = {}
+
+    backend_kwargs = {
+        **backend_kwarg_defaults(),
+        **backend_kwargs,
+    }
+
+    (figsize, ax_labelsize, titlesize, xt_labelsize, _linewidth, _) = _scale_fig_size(
+        figsize, textsize, rows, cols
+    )
+    backend_kwargs.setdefault("figsize", figsize)
+    backend_kwargs.setdefault("squeeze", True)
+
+    if kind == "hist":
+        kwargs = matplotlib_kwarg_dealiaser(kwargs, "hist")
+    else:
+        kwargs = matplotlib_kwarg_dealiaser(kwargs, "plot")
+    kwargs.setdefault("linewidth", _linewidth)
+
     if ax is None:
-        _, ax = _create_axes_grid(
+        _, ax = create_axes_grid(
             length_plotters,
             rows,
             cols,
-            figsize=figsize,
-            squeeze=False,
             backend_kwargs=backend_kwargs,
         )
     idx = 0
@@ -59,6 +76,7 @@ def plot_posterior(
             selection,
             ax=ax_,
             bw=bw,
+            circular=circular,
             bins=bins,
             kind=kind,
             point_estimate=point_estimate,
@@ -69,7 +87,7 @@ def plot_posterior(
             rope=rope,
             ax_labelsize=ax_labelsize,
             xt_labelsize=xt_labelsize,
-            **kwargs
+            **kwargs,
         )
         idx += 1
         ax_.set_title(make_label(var_name, selection), fontsize=titlesize, wrap=True)
@@ -87,6 +105,7 @@ def _plot_posterior_op(
     selection,
     ax,
     bw,
+    circular,
     linewidth,
     bins,
     kind,
@@ -97,8 +116,8 @@ def _plot_posterior_op(
     rope,
     ax_labelsize,
     xt_labelsize,
-    round_to: Optional[int] = None,
-    **kwargs
+    round_to=None,
+    **kwargs,
 ):  # noqa: D202
     """Artist to draw posterior."""
 
@@ -175,14 +194,28 @@ def _plot_posterior_op(
             zorder=0,
             alpha=0.7,
         )
-        text_props = {"size": ax_labelsize, "horizontalalignment": "center", "color": "C2"}
-        ax.text(vals[0], plot_height * 0.2, vals[0], weight="semibold", **text_props)
-        ax.text(vals[1], plot_height * 0.2, vals[1], weight="semibold", **text_props)
+        text_props = {"size": ax_labelsize, "color": "C2"}
+        ax.text(
+            vals[0],
+            plot_height * 0.2,
+            f"{vals[0]} ",
+            weight="semibold",
+            horizontalalignment="right",
+            **text_props,
+        )
+        ax.text(
+            vals[1],
+            plot_height * 0.2,
+            f" {vals[1]}",
+            weight="semibold",
+            horizontalalignment="left",
+            **text_props,
+        )
 
     def display_point_estimate():
         if not point_estimate:
             return
-        point_value = calculate_point_estimate(point_estimate, values, bw)
+        point_value = calculate_point_estimate(point_estimate, values, bw, circular)
         sig_figs = format_sig_figs(point_value, round_to)
         point_text = "{point_estimate}={point_value:.{sig_figs}g}".format(
             point_estimate=point_estimate, point_value=point_value, sig_figs=sig_figs
@@ -211,16 +244,16 @@ def _plot_posterior_op(
             ax.text(
                 hdi_i[0],
                 plot_height * 0.07,
-                round_num(hdi_i[0], round_to),
+                round_num(hdi_i[0], round_to) + " ",
                 size=ax_labelsize,
-                horizontalalignment="center",
+                horizontalalignment="right",
             )
             ax.text(
                 hdi_i[1],
                 plot_height * 0.07,
-                round_num(hdi_i[1], round_to),
+                " " + round_num(hdi_i[1], round_to),
                 size=ax_labelsize,
-                horizontalalignment="center",
+                horizontalalignment="left",
             )
             ax.text(
                 (hdi_i[0] + hdi_i[1]) / 2,
@@ -247,6 +280,7 @@ def _plot_posterior_op(
         plot_kde(
             values,
             bw=bw,
+            circular=circular,
             fill_kwargs={"alpha": kwargs.pop("fill_alpha", 0)},
             plot_kwargs=kwargs,
             ax=ax,
