@@ -1,17 +1,15 @@
 """Matplotlib Posterior predictive plot."""
-import platform
 import logging
-from matplotlib import animation, get_backend
+import platform
+
 import matplotlib.pyplot as plt
 import numpy as np
+from matplotlib import animation, get_backend
 
-from . import backend_show
+from ....stats.density_utils import get_bins, histogram, kde
 from ...kdeplot import plot_kde
-from ...plot_utils import (
-    make_label,
-    _create_axes_grid,
-)
-from ....numeric_utils import _fast_kde, histogram, get_bins
+from ...plot_utils import _scale_fig_size, make_label
+from . import backend_kwarg_defaults, backend_show, create_axes_grid
 
 _log = logging.getLogger(__name__)
 
@@ -29,21 +27,48 @@ def plot_ppc(
     pp_sample_ix,
     kind,
     alpha,
-    linewidth,
+    color,
+    textsize,
     mean,
-    xt_labelsize,
-    ax_labelsize,
     jitter,
     total_pp_samples,
     legend,
     group,
-    markersize,
     animation_kwargs,
     num_pp_samples,
     backend_kwargs,
     show,
 ):
     """Matplotlib ppc plot."""
+    if backend_kwargs is None:
+        backend_kwargs = {}
+
+    backend_kwargs = {
+        **backend_kwarg_defaults(),
+        **backend_kwargs,
+    }
+
+    if animation_kwargs is None:
+        animation_kwargs = {}
+    if platform.system() == "Linux":
+        animation_kwargs.setdefault("blit", True)
+    else:
+        animation_kwargs.setdefault("blit", False)
+
+    if alpha is None:
+        if animated:
+            alpha = 1
+        else:
+            if kind.lower() == "scatter":
+                alpha = 0.7
+            else:
+                alpha = 0.2
+
+    if jitter is None:
+        jitter = 0.0
+    if jitter < 0.0:
+        raise ValueError("jitter must be >=0")
+
     if animated:
         try:
             shell = get_ipython().__class__.__name__
@@ -64,10 +89,13 @@ def plot_ppc(
                 "(e.g. to TkAgg)"
             )
 
+    (figsize, ax_labelsize, _, xt_labelsize, linewidth, markersize) = _scale_fig_size(
+        figsize, textsize, rows, cols
+    )
+    backend_kwargs.setdefault("figsize", figsize)
+    backend_kwargs.setdefault("squeeze", True)
     if ax is None:
-        fig, axes = _create_axes_grid(
-            length_plotters, rows, cols, figsize=figsize, backend_kwargs=backend_kwargs
-        )
+        fig, axes = create_axes_grid(length_plotters, rows, cols, backend_kwargs=backend_kwargs)
     else:
         axes = np.ravel(ax)
         if len(axes) != length_plotters:
@@ -81,7 +109,7 @@ def plot_ppc(
             if not all([ax.get_figure() is fig for ax in axes]):
                 raise ValueError("All axes must be on the same figure for animation to work")
 
-    for i, ax_i in enumerate(axes):
+    for i, ax_i in enumerate(np.ravel(axes)[:length_plotters]):
         var_name, selection, obs_vals = obs_plotters[i]
         pp_var_name, _, pp_vals = pp_plotters[i]
         dtype = predictive_dataset[pp_var_name].dtype.kind
@@ -92,11 +120,11 @@ def plot_ppc(
         pp_sampled_vals = pp_vals[pp_sample_ix]
 
         if kind == "kde":
-            plot_kwargs = {"color": "C5", "alpha": alpha, "linewidth": 0.5 * linewidth}
+            plot_kwargs = {"color": color, "alpha": alpha, "linewidth": 0.5 * linewidth}
             if dtype == "i":
                 plot_kwargs["drawstyle"] = "steps-pre"
             ax_i.plot(
-                [], color="C5", label="{} predictive {}".format(group.capitalize(), pp_var_name)
+                [], color=color, label="{} predictive {}".format(group.capitalize(), pp_var_name)
             )
 
             if dtype == "f":
@@ -127,8 +155,7 @@ def plot_ppc(
             for vals in pp_sampled_vals:
                 vals = np.array([vals]).flatten()
                 if dtype == "f":
-                    pp_density, lower, upper = _fast_kde(vals)
-                    pp_x = np.linspace(lower, upper, len(pp_density))
+                    pp_x, pp_density = kde(vals)
                     pp_densities.append(pp_density)
                     pp_xs.append(pp_x)
                 else:
@@ -165,9 +192,9 @@ def plot_ppc(
                     ax_i.plot(
                         new_x,
                         new_d.mean(0),
-                        color="C0",
+                        color=color,
                         linestyle="--",
-                        linewidth=linewidth,
+                        linewidth=linewidth * 1.5,
                         zorder=2,
                         label=label,
                     )
@@ -179,8 +206,8 @@ def plot_ppc(
                     ax_i.plot(
                         bin_edges,
                         hist,
-                        color="C0",
-                        linewidth=linewidth,
+                        color=color,
+                        linewidth=linewidth * 1.5,
                         label=label,
                         zorder=2,
                         linestyle="--",
@@ -193,7 +220,7 @@ def plot_ppc(
             drawstyle = "default" if dtype == "f" else "steps-pre"
             ax_i.plot(
                 *_empirical_cdf(obs_vals),
-                color="k",
+                color=color,
                 linewidth=linewidth,
                 label="Observed {}".format(var_name),
                 drawstyle=drawstyle,
@@ -218,15 +245,19 @@ def plot_ppc(
                     pp_densities[2 * idx + 1] = pp_density
 
                 ax_i.plot(
-                    *pp_densities, alpha=alpha, color="C5", drawstyle=drawstyle, linewidth=linewidth
+                    *pp_densities,
+                    alpha=alpha,
+                    color=color,
+                    drawstyle=drawstyle,
+                    linewidth=linewidth
                 )
-            ax_i.plot([], color="C5", label="Posterior predictive {}".format(pp_var_name))
+            ax_i.plot([], color=color, label="Posterior predictive {}".format(pp_var_name))
             if mean:
                 ax_i.plot(
                     *_empirical_cdf(pp_vals.flatten()),
-                    color="C0",
+                    color=color,
                     linestyle="--",
-                    linewidth=linewidth,
+                    linewidth=linewidth * 1.5,
                     drawstyle=drawstyle,
                     label="Posterior predictive mean {}".format(pp_var_name)
                 )
@@ -238,9 +269,9 @@ def plot_ppc(
                     plot_kde(
                         pp_vals.flatten(),
                         plot_kwargs={
-                            "color": "C0",
+                            "color": color,
                             "linestyle": "--",
-                            "linewidth": linewidth,
+                            "linewidth": linewidth * 1.5,
                             "zorder": 3,
                         },
                         label="Posterior predictive mean {}".format(pp_var_name),
@@ -255,8 +286,8 @@ def plot_ppc(
                     ax_i.plot(
                         bin_edges,
                         hist,
-                        color="C0",
-                        linewidth=linewidth,
+                        color=color,
+                        linewidth=linewidth * 1.5,
                         label="Posterior predictive mean {}".format(pp_var_name),
                         zorder=3,
                         linestyle="--",
@@ -277,7 +308,7 @@ def plot_ppc(
                 obs_vals,
                 obs_yvals,
                 "o",
-                color="C0",
+                color=color,
                 markersize=markersize,
                 alpha=alpha,
                 label="Observed {}".format(var_name),
@@ -289,6 +320,7 @@ def plot_ppc(
                     pp_sampled_vals,
                     ax_i,
                     kind=kind,
+                    color=color,
                     height=y_rows.mean() * 0.5,
                     markersize=markersize,
                 )
@@ -300,10 +332,12 @@ def plot_ppc(
                     if jitter:
                         yvals += np.random.uniform(low=scale_low, high=scale_high, size=len(vals))
                     ax_i.plot(
-                        vals, yvals, "o", zorder=2, color="C5", markersize=markersize, alpha=alpha
+                        vals, yvals, "o", zorder=2, color=color, markersize=markersize, alpha=alpha
                     )
 
-            ax_i.plot([], "C5o", label="Posterior predictive {}".format(pp_var_name))
+            ax_i.plot(
+                [], color=color, marker="o", label="Posterior predictive {}".format(pp_var_name)
+            )
 
             ax_i.set_yticks([])
 
@@ -337,6 +371,7 @@ def _set_animation(
     dtype=None,
     kind="density",
     alpha=None,
+    color=None,
     drawstyle=None,
     linewidth=None,
     height=None,
@@ -346,20 +381,15 @@ def _set_animation(
     if kind == "kde":
         length = len(pp_sampled_vals)
         if dtype == "f":
-            y_vals, lower, upper = _fast_kde(pp_sampled_vals[0])
-            x_vals = np.linspace(lower, upper, len(y_vals))
-
-            max_max = max([max(_fast_kde(pp_sampled_vals[i])[0]) for i in range(length)])
-
+            x_vals, y_vals = kde(pp_sampled_vals[0])
+            max_max = max([max(kde(pp_sampled_vals[i])[1]) for i in range(length)])
             ax.set_ylim(0, max_max)
-
             (line,) = ax.plot(x_vals, y_vals, **plot_kwargs)
 
             def animate(i):
-                y_vals, lower, upper = _fast_kde(pp_sampled_vals[i])
-                x_vals = np.linspace(lower, upper, len(y_vals))
+                x_vals, y_vals = kde(pp_sampled_vals[i])
                 line.set_data(x_vals, y_vals)
-                return line
+                return (line,)
 
         else:
             vals = pp_sampled_vals[0]
@@ -380,31 +410,31 @@ def _set_animation(
     elif kind == "cumulative":
         x_vals, y_vals = _empirical_cdf(pp_sampled_vals[0])
         (line,) = ax.plot(
-            x_vals, y_vals, alpha=alpha, color="C5", drawstyle=drawstyle, linewidth=linewidth
+            x_vals, y_vals, alpha=alpha, color=color, drawstyle=drawstyle, linewidth=linewidth
         )
 
         def animate(i):
             x_vals, y_vals = _empirical_cdf(pp_sampled_vals[i])
             line.set_data(x_vals, y_vals)
-            return line
+            return (line,)
 
     elif kind == "scatter":
         x_vals = pp_sampled_vals[0]
         y_vals = np.full_like(x_vals, height, dtype=np.float64)
         (line,) = ax.plot(
-            x_vals, y_vals, "o", zorder=2, color="C5", markersize=markersize, alpha=alpha
+            x_vals, y_vals, "o", zorder=2, color=color, markersize=markersize, alpha=alpha
         )
 
         def animate(i):
             line.set_xdata(np.ravel(pp_sampled_vals[i]))
-            return line
+            return (line,)
 
     def init():
         if kind != "scatter":
             line.set_data([], [])
         else:
             line.set_xdata([])
-        return line
+        return (line,)
 
     return animate, init
 
