@@ -1,26 +1,28 @@
 # pylint: disable=unexpected-keyword-arg
 """Plot distribution as histogram or kernel density estimates."""
-
+import numpy as np
 import xarray as xr
-from .plot_utils import get_plotting_function, matplotlib_kwarg_dealiaser
-from ..numeric_utils import get_bins
+
 from ..data import InferenceData
 from ..rcparams import rcParams
+from .plot_utils import get_plotting_function
 
 
 def plot_dist(
     values,
     values2=None,
-    color=None,
+    color="C0",
     kind="auto",
     cumulative=False,
     label=None,
     rotated=False,
     rug=False,
-    bw=4.5,
+    bw="default",
+    circular=False,
     quantiles=None,
     contour=True,
     fill_last=True,
+    figsize=None,
     textsize=None,
     plot_kwargs=None,
     fill_kwargs=None,
@@ -29,6 +31,7 @@ def plot_dist(
     contourf_kwargs=None,
     pcolormesh_kwargs=None,
     hist_kwargs=None,
+    is_circular=False,
     ax=None,
     backend=None,
     backend_kwargs=None,
@@ -59,10 +62,16 @@ def plot_dist(
         Whether to rotate the 1D KDE plot 90 degrees.
     rug : bool
         If True adds a rugplot. Defaults to False. Ignored for 2D KDE
-    bw : float
-        Bandwidth scaling factor for 1D KDE. Should be larger than 0. The higher this number the
-        smoother the KDE will be. Defaults to 4.5 which is essentially the same as the Scott's
-        rule of thumb (the default rule used by SciPy).
+    bw: Optional[float or str]
+        If numeric, indicates the bandwidth and must be positive.
+        If str, indicates the method to estimate the bandwidth and must be
+        one of "scott", "silverman", "isj" or "experimental" when `circular` is False
+        and "taylor" (for now) when `circular` is True.
+        Defaults to "default" which means "experimental" when variable is not circular
+        and "taylor" when it is.
+    circular: Optional[bool]
+        If True, it interprets the values passed are from a circular variable measured in radians
+        and a circular KDE is used. Only valid for 1D KDE. Defaults to False.
     quantiles : list
         Quantiles in ascending order used to segment the KDE. Use [.25, .5, .75] for quartiles.
         Defaults to None.
@@ -70,6 +79,8 @@ def plot_dist(
         If True plot the 2D KDE using contours, otherwise plot a smooth 2D KDE. Defaults to True.
     fill_last : bool
         If True fill the last contour of the 2D KDE plot. Defaults to True.
+    figsize : tuple
+        Figure size. If None it will be defined automatically.
     textsize: float
         Text size scaling factor for labels, titles and lines. If None it will be autoscaled based
         on figsize. Not implemented for bokeh backend.
@@ -90,6 +101,9 @@ def plot_dist(
         Keywords passed to ax.pcolormesh. Ignored for 1D KDE.
     hist_kwargs : dict
         Keywords passed to the histogram.
+    is_circular : {False, True, "radians", "degrees"}. Default False.
+        Select input type {"radians", "degrees"} for circular histogram or KDE plot. If True,
+        default input type is "radians".
     ax: axes, optional
         Matplotlib axes or bokeh figures.
     backend: str, optional
@@ -145,6 +159,8 @@ def plot_dist(
 
         >>> az.plot_dist(b, rug=True, quantiles=[.25, .5, .75], cumulative=True)
     """
+    values = np.asarray(values)
+
     if isinstance(values, (InferenceData, xr.Dataset)):
         raise ValueError(
             "InferenceData or xarray.Dateset object detected,"
@@ -158,21 +174,6 @@ def plot_dist(
     if kind == "auto":
         kind = "hist" if values.dtype.kind == "i" else "kde"
 
-    if kind == "hist":
-        hist_kwargs = matplotlib_kwarg_dealiaser(hist_kwargs, "hist")
-        hist_kwargs.setdefault("bins", get_bins(values))
-        hist_kwargs.setdefault("cumulative", cumulative)
-        hist_kwargs.setdefault("color", color)
-        hist_kwargs.setdefault("label", label)
-        hist_kwargs.setdefault("rwidth", 0.9)
-        hist_kwargs.setdefault("align", "left")
-        hist_kwargs.setdefault("density", True)
-
-        if rotated:
-            hist_kwargs.setdefault("orientation", "horizontal")
-        else:
-            hist_kwargs.setdefault("orientation", "vertical")
-
     dist_plot_args = dict(
         # User Facing API that can be simplified
         values=values,
@@ -184,9 +185,11 @@ def plot_dist(
         rotated=rotated,
         rug=rug,
         bw=bw,
+        circular=circular,
         quantiles=quantiles,
         contour=contour,
         fill_last=fill_last,
+        figsize=figsize,
         textsize=textsize,
         plot_kwargs=plot_kwargs,
         fill_kwargs=fill_kwargs,
@@ -197,6 +200,7 @@ def plot_dist(
         hist_kwargs=hist_kwargs,
         ax=ax,
         backend_kwargs=backend_kwargs,
+        is_circular=is_circular,
         show=show,
         **kwargs,
     )
