@@ -1,24 +1,16 @@
 """Plot pointwise elpd estimations of inference data."""
 import numpy as np
-import matplotlib.pyplot as plt
-import matplotlib.cm as cm
-from matplotlib.lines import Line2D
 
 from ..data import convert_to_inference_data
-from .plot_utils import (
-    format_coords_as_labels,
-    color_from_dim,
-    get_plotting_function,
-    matplotlib_kwarg_dealiaser,
-)
-from ..stats import waic, loo, ELPDData
 from ..rcparams import rcParams
+from ..stats import ELPDData, loo, waic
 from ..utils import get_coords
+from .plot_utils import format_coords_as_labels, get_plotting_function
 
 
 def plot_elpd(
     compare_dict,
-    color=None,
+    color="C0",
     xlabels=False,
     figsize=None,
     textsize=None,
@@ -121,7 +113,7 @@ def plot_elpd(
             )
         )
     ic_fun = loo if ic == "loo" else waic
-    handles = None
+
     # Make sure all object are ELPDData
     for k, item in compare_dict.items():
         if not isinstance(item, ELPDData):
@@ -150,53 +142,15 @@ def plot_elpd(
     if coords is None:
         coords = {}
 
-    plot_kwargs = matplotlib_kwarg_dealiaser(plot_kwargs, "scatter")
-
-    if backend == "bokeh":
-        plot_kwargs.setdefault("marker", rcParams["plot.bokeh.marker"])
-
     pointwise_data = [
         get_coords(compare_dict[model]["{}_i".format(ic)], coords) for model in models
     ]
     xdata = np.arange(pointwise_data[0].size)
     coord_labels = format_coords_as_labels(pointwise_data[0]) if xlabels else None
 
-    markersize = None
-    if isinstance(color, str):
-        if color in pointwise_data[0].dims:
-            colors, color_mapping = color_from_dim(pointwise_data[0], color)
-            if legend and backend != "bokeh":
-                cmap_name = plot_kwargs.pop("cmap", plt.rcParams["image.cmap"])
-                markersize = plot_kwargs.pop("s", plt.rcParams["lines.markersize"])
-                cmap = getattr(cm, cmap_name)
-                handles = [
-                    Line2D(
-                        [],
-                        [],
-                        color=cmap(float_color),
-                        label=coord,
-                        ms=markersize,
-                        lw=0,
-                        **plot_kwargs
-                    )
-                    for coord, float_color in color_mapping.items()
-                ]
-                plot_kwargs.setdefault("cmap", cmap_name)
-                plot_kwargs.setdefault("s", markersize ** 2)
-            plot_kwargs.setdefault("c", colors)
-        else:
-            plot_kwargs.setdefault("c", color)
-            legend = False
-    else:
-        legend = False
-        plot_kwargs.setdefault("c", color)
-
     if numvars < 2:
         raise Exception("Number of models to compare must be 2 or greater.")
 
-    # flatten data (data must be flattened after selecting, labeling and coloring)
-    pointwise_data = [pointwise.values.flatten() for pointwise in pointwise_data]
-
     elpd_plot_kwargs = dict(
         ax=ax,
         models=models,
@@ -205,23 +159,16 @@ def plot_elpd(
         figsize=figsize,
         textsize=textsize,
         plot_kwargs=plot_kwargs,
-        markersize=markersize,
         xlabels=xlabels,
         coord_labels=coord_labels,
         xdata=xdata,
         threshold=threshold,
         legend=legend,
-        handles=handles,
         color=color,
         backend_kwargs=backend_kwargs,
         show=show,
     )
 
-    if backend == "bokeh":
-        elpd_plot_kwargs.pop("legend")
-        elpd_plot_kwargs.pop("handles")
-        elpd_plot_kwargs.pop("color")
-
     # TODO: Add backend kwargs
     plot = get_plotting_function("plot_elpd", "elpdplot", backend)
     ax = plot(**elpd_plot_kwargs)
