@@ -1,11 +1,7 @@
 """Plot energy transition distribution in HMC inference."""
-from itertools import cycle
-from matplotlib.pyplot import rcParams as mpl_rcParams
-import numpy as np
-
 from ..data import convert_to_dataset
-from .plot_utils import _scale_fig_size, get_plotting_function, matplotlib_kwarg_dealiaser
 from ..rcparams import rcParams
+from .plot_utils import get_plotting_function
 
 
 def plot_energy(
@@ -16,7 +12,7 @@ def plot_energy(
     legend=True,
     fill_alpha=(1, 0.75),
     fill_color=("C0", "C5"),
-    bw=4.5,
+    bw="experimental",
     textsize=None,
     fill_kwargs=None,
     plot_kwargs=None,
@@ -47,10 +43,11 @@ def plot_energy(
     fill_color : tuple of valid matplotlib color
         Color for Marginal energy distribution and Energy transition distribution.
         Defaults to ('C0', 'C5')
-    bw : float
-        Bandwidth scaling factor for the KDE. Should be larger than 0. The higher this number the
-        smoother the KDE will be. Defaults to 4.5 which is essentially the same as the Scott's rule
-        of thumb (the default rule used by SciPy). Only works if `kind='kde'`
+    bw: float or str, optional
+        If numeric, indicates the bandwidth and must be positive.
+        If str, indicates the method to estimate the bandwidth and must be
+        one of "scott", "silverman", "isj" or "experimental". Defaults to "experimental"
+        Only works if `kind='kde'`
     textsize: float
         Text size scaling factor for labels, titles and lines. If None it will be autoscaled based
         on figsize.
@@ -93,40 +90,15 @@ def plot_energy(
     """
     energy = convert_to_dataset(data, group="sample_stats").energy.values
 
-    fill_kwargs = matplotlib_kwarg_dealiaser(fill_kwargs, "hexbin")
-    types = "hist" if kind in {"hist", "histogram"} else "plot"
-    plot_kwargs = matplotlib_kwarg_dealiaser(plot_kwargs, types)
-
-    figsize, _, _, xt_labelsize, linewidth, _ = _scale_fig_size(figsize, textsize, 1, 1)
-
-    _colors = [
-        prop for _, prop in zip(range(10), cycle(mpl_rcParams["axes.prop_cycle"].by_key()["color"]))
-    ]
-    if (fill_color[0].startswith("C") and len(fill_color[0]) == 2) and (
-        fill_color[1].startswith("C") and len(fill_color[1]) == 2
-    ):
-        fill_color = tuple([_colors[int(color[1:]) % 10] for color in fill_color])
-    elif fill_color[0].startswith("C") and len(fill_color[0]) == 2:
-        fill_color = tuple([_colors[int(fill_color[0][1:]) % 10]] + list(fill_color[1:]))
-    elif fill_color[1].startswith("C") and len(fill_color[1]) == 2:
-        fill_color = tuple(list(fill_color[1:]) + [_colors[int(fill_color[0][1:]) % 10]])
-
-    series = zip(
-        fill_alpha,
-        fill_color,
-        ("Marginal Energy", "Energy transition"),
-        (energy - energy.mean(), np.diff(energy)),
-    )
-
     plot_energy_kwargs = dict(
         ax=ax,
-        series=series,
         energy=energy,
         kind=kind,
         bfmi=bfmi,
         figsize=figsize,
-        xt_labelsize=xt_labelsize,
-        linewidth=linewidth,
+        textsize=textsize,
+        fill_alpha=fill_alpha,
+        fill_color=fill_color,
         fill_kwargs=fill_kwargs,
         plot_kwargs=plot_kwargs,
         bw=bw,
@@ -139,13 +111,6 @@ def plot_energy(
         backend = rcParams["plot.backend"]
     backend = backend.lower()
 
-    if backend == "bokeh":
-
-        plot_energy_kwargs.pop("xt_labelsize")
-        plot_energy_kwargs["line_width"] = plot_energy_kwargs.pop("linewidth")
-        if kind in {"hist", "histogram"}:
-            plot_energy_kwargs["legend"] = False
-
     # TODO: Add backend kwargs
     plot = get_plotting_function("plot_energy", "energyplot", backend)
     ax = plot(**plot_energy_kwargs)
