@@ -1,20 +1,18 @@
 """Utilities for plotting."""
-import warnings
-from typing import Dict, Any
-from itertools import product, tee
 import importlib
-from scipy.stats import mode
-from matplotlib.colors import to_hex
+import warnings
+from itertools import product, tee
+from typing import Any, Dict
 
-import packaging
-import numpy as np
-import matplotlib.pyplot as plt
 import matplotlib as mpl
-import matplotlib.cbook as cbook
+import numpy as np
+import packaging
 import xarray as xr
+from matplotlib.colors import to_hex
+from scipy.stats import mode
 
-from ..numeric_utils import _fast_kde
 from ..rcparams import rcParams
+from ..stats.density_utils import kde
 
 KwargSpec = Dict[str, Any]
 
@@ -132,84 +130,6 @@ def default_grid(n_items, max_cols=4, min_cols=3):  # noqa: D202
     return n_items // ideal + 1, ideal
 
 
-def _create_axes_grid(length_plotters, rows, cols, backend=None, backend_kwargs=None, **kwargs):
-    """Create figure and axes for grids with multiple plots.
-
-    Parameters
-    ----------
-    n_items : int
-        Number of panels required
-    rows : int
-        Number of rows
-    cols : int
-        Number of columns
-    backend: str, optional
-        Select plotting backend {"matplotlib","bokeh"}. Default "matplotlib".
-    backend_kwargs: dict, optional
-        kwargs for backend figure.
-
-    Returns
-    -------
-    fig : matplotlib figure
-    ax : matplotlib axes
-    """
-    if backend_kwargs is None:
-        backend_kwargs = {}
-
-    if backend is None:
-        backend = rcParams["plot.backend"]
-    backend = backend.lower()
-
-    if backend == "bokeh":
-        from bokeh.plotting import figure
-        from .backends.bokeh import backend_kwarg_defaults
-
-        backend_kwargs = {
-            **backend_kwarg_defaults(("dpi", "plot.bokeh.figure.dpi"),),
-            **backend_kwargs,
-        }
-        dpi = backend_kwargs.pop("dpi")
-        if "figsize" in kwargs:
-            figsize = kwargs["figsize"]
-            backend_kwargs.setdefault("width", int(figsize[0] * dpi / cols))
-            backend_kwargs.setdefault("height", int(figsize[1] * dpi / rows))
-
-        sharex = kwargs.get("sharex", False)
-        sharey = kwargs.get("sharey", False)
-        fig = None
-        ax = []
-        extra = (rows * cols) - length_plotters
-        for row in range(rows):
-            row_ax = []
-            for col in range(cols):
-                if (row == 0) and (col == 0) and (sharex or sharey):
-                    bokeh_ax = figure(**backend_kwargs)
-                    row_ax.append(bokeh_ax)
-                    if sharex:
-                        backend_kwargs["x_range"] = bokeh_ax.x_range
-                    if sharey:
-                        backend_kwargs["y_range"] = bokeh_ax.y_range
-                else:
-                    if row * cols + (col + 1) > length_plotters:
-                        row_ax.append(None)
-                    else:
-                        row_ax.append(figure(**backend_kwargs))
-            ax.append(row_ax)
-        ax = np.array(ax)
-    else:
-        from .backends.matplotlib import backend_kwarg_defaults
-
-        backend_kwargs = {**backend_kwarg_defaults(), **backend_kwargs, **kwargs}
-        fig, ax = plt.subplots(rows, cols, **backend_kwargs)
-        ax = np.ravel(ax)
-        extra = (rows * cols) - length_plotters
-        if extra:
-            for i in range(1, extra + 1):
-                ax[-i].set_axis_off()
-            ax = ax[:-extra]
-    return fig, ax
-
-
 def selection_to_string(selection):
     """Convert dictionary of coordinates to a string for labels.
 
@@ -580,12 +500,12 @@ def get_plotting_function(plot_name, plot_module, backend):
 
     try:
         backend = _backend[backend]
-    except KeyError:
+    except KeyError as err:
         raise KeyError(
             "Backend {} is not implemented. Try backend in {}".format(
                 backend, set(_backend.values())
             )
-        )
+        ) from err
 
     if backend == "bokeh":
         try:
@@ -593,10 +513,10 @@ def get_plotting_function(plot_name, plot_module, backend):
 
             assert packaging.version.parse(bokeh.__version__) >= packaging.version.parse("1.4.0")
 
-        except (ImportError, AssertionError):
+        except (ImportError, AssertionError) as err:
             raise ImportError(
                 "'bokeh' backend needs Bokeh (1.4.0+) installed." " Please upgrade or install"
-            )
+            ) from err
 
     # Perform import of plotting method
     # TODO: Convert module import to top level for all plots
@@ -611,7 +531,7 @@ def get_plotting_function(plot_name, plot_module, backend):
     return plotting_method
 
 
-def calculate_point_estimate(point_estimate, values, bw=4.5):
+def calculate_point_estimate(point_estimate, values, bw="default", circular=False):
     """Validate and calculate the point estimate.
 
     Parameters
@@ -620,10 +540,16 @@ def calculate_point_estimate(point_estimate, values, bw=4.5):
         Plot point estimate per variable. Values should be 'mean', 'median', 'mode' or None.
         Defaults to 'auto' i.e. it falls back to default set in rcParams.
     values : 1-d array
-    bw : float
-        Bandwidth scaling factor. Should be larger than 0. The higher this number the smoother the
-        KDE will be. Defaults to 4.5 which is essentially the same as the Scott's rule of thumb
-        (the default used rule by SciPy).
+    bw: Optional[float or str]
+        If numeric, indicates the bandwidth and must be positive.
+        If str, indicates the method to estimate the bandwidth and must be
+        one of "scott", "silverman", "isj" or "experimental" when `circular` is False
+        and "taylor" (for now) when `circular` is True.
+        Defaults to "default" which means "experimental" when variable is not circular
+        and "taylor" when it is.
+    circular: Optional[bool]
+        If True, it interprets the values passed are from a circular variable measured in radians
+        and a circular KDE is used. Only valid for 1D KDE. Defaults to False.
 
     Returns
     -------
@@ -643,8 +569,12 @@ def calculate_point_estimate(point_estimate, values, bw=4.5):
         point_value = values.mean()
     elif point_estimate == "mode":
         if isinstance(values[0], float):
-            density, lower, upper = _fast_kde(values, bw=bw)
-            x = np.linspace(lower, upper, len(density))
+            if bw == "default":
+                if circular:
+                    bw = "taylor"
+                else:
+                    bw = "experimental"
+            x, density = kde(values, circular=circular, bw=bw)
             point_value = x[np.argmax(density)]
         else:
             point_value = mode(values)[0][0]
@@ -654,44 +584,70 @@ def calculate_point_estimate(point_estimate, values, bw=4.5):
     return point_value
 
 
-def matplotlib_kwarg_dealiaser(args, kind, backend="matplotlib"):
-    """De-aliase the kwargs passed to plots."""
-    if args is None:
-        return {}
-    matplotlib_kwarg_dealiaser_dict = {
-        "scatter": mpl.collections.PathCollection,
-        "plot": mpl.lines.Line2D,
-        "hist": mpl.patches.Patch,
-        "hexbin": mpl.collections.PolyCollection,
-        "fill_between": mpl.collections.PolyCollection,
-        "hlines": mpl.collections.LineCollection,
-        "text": mpl.text.Text,
-        "contour": mpl.contour.ContourSet,
-        "pcolormesh": mpl.collections.QuadMesh,
-    }
-    if backend == "matplotlib":
-        return cbook.normalize_kwargs(
-            args, getattr(matplotlib_kwarg_dealiaser_dict[kind], "_alias_map", {})
-        )
-    return args
+def is_valid_quantile(value):
+    """Check if value is a number between 0 and 1."""
+    try:
+        value = float(value)
+        return 0 < value < 1
+    except ValueError:
+        return False
 
 
-def _dealiase_sel_kwargs(kwargs, prop_dict, idx):
-    """Generate kwargs dict from kwargs and prop_dict.
+def sample_reference_distribution(dist, shape):
+    """Generate samples from a scipy distribution with a given shape."""
+    x_ss = []
+    densities = []
+    dist_rvs = dist.rvs(size=shape)
+    for idx in range(shape[1]):
+        x_s, density = kde(dist_rvs[:, idx])
+        x_ss.append(x_s)
+        densities.append(density)
+    return np.array(x_ss).T, np.array(densities).T
 
-    Gets property at position ``idx`` for each property in prop_dict and adds it to
-    ``kwargs``. Values in prop_dict are dealiased and overwrite values in
-    kwargs with the same key .
 
-    Parameters
-    ----------
-    kwargs : dict
-    prop_dict : dict of {str : array_like}
-    idx : int
-    """
-    return {
-        **kwargs,
-        **matplotlib_kwarg_dealiaser(
-            {prop: props[idx] for prop, props in prop_dict.items()}, "plot"
-        ),
-    }
+def set_bokeh_circular_ticks_labels(ax, hist, labels):
+    """Place ticks and ticklabels on Bokeh's circular histogram."""
+    ticks = np.linspace(-np.pi, np.pi, len(labels), endpoint=False)
+    ax.annular_wedge(
+        x=0,
+        y=0,
+        inner_radius=0,
+        outer_radius=np.max(hist) * 1.1,
+        start_angle=ticks,
+        end_angle=ticks,
+        line_color="grey",
+    )
+
+    radii_circles = np.linspace(0, np.max(hist) * 1.1, 4)
+    ax.circle(0, 0, radius=radii_circles, fill_color=None, line_color="grey")
+
+    offset = np.max(hist * 1.05) * 0.15
+    ticks_labels_pos_1 = np.max(hist * 1.05)
+    ticks_labels_pos_2 = ticks_labels_pos_1 * np.sqrt(2) / 2
+
+    ax.text(
+        [
+            ticks_labels_pos_1 + offset,
+            ticks_labels_pos_2 + offset,
+            0,
+            -ticks_labels_pos_2 - offset,
+            -ticks_labels_pos_1 - offset,
+            -ticks_labels_pos_2 - offset,
+            0,
+            ticks_labels_pos_2 + offset,
+        ],
+        [
+            0,
+            ticks_labels_pos_2 + offset / 2,
+            ticks_labels_pos_1 + offset,
+            ticks_labels_pos_2 + offset / 2,
+            0,
+            -ticks_labels_pos_2 - offset,
+            -ticks_labels_pos_1 - offset,
+            -ticks_labels_pos_2 - offset,
+        ],
+        text=labels,
+        text_align="center",
+    )
+
+    return ax
