@@ -1,31 +1,30 @@
 # pylint: disable=too-many-lines
 """Statistical functions in ArviZ."""
-import warnings
 import logging
+import warnings
 from collections import OrderedDict
 from copy import deepcopy
-from typing import Optional, List, Union
+from typing import List, Optional, Union
 
 import numpy as np
 import pandas as pd
 import scipy.stats as st
-from scipy.optimize import minimize
 import xarray as xr
+from scipy.optimize import minimize
 
-from ..data import convert_to_inference_data, convert_to_dataset, InferenceData, CoordSpec, DimSpec
-from .diagnostics import _multichain_statistics, _mc_error, ess
-from .stats_utils import (
-    make_ufunc as _make_ufunc,
-    wrap_xarray_ufunc as _wrap_xarray_ufunc,
-    logsumexp as _logsumexp,
-    ELPDData,
-    stats_variance_2d as svar,
-    _circular_standard_deviation,
-    get_log_likelihood as _get_log_likelihood,
-)
-from ..numeric_utils import _fast_kde, histogram, get_bins
-from ..utils import _var_names, Numba, _numba_var, get_coords, credible_interval_warning
+from ..data import CoordSpec, DimSpec, InferenceData, convert_to_dataset, convert_to_inference_data
 from ..rcparams import rcParams
+from ..utils import Numba, _numba_var, _var_names, credible_interval_warning, get_coords
+from .density_utils import get_bins as _get_bins
+from .density_utils import histogram as _histogram
+from .density_utils import kde as _kde
+from .diagnostics import _mc_error, _multichain_statistics, ess
+from .stats_utils import ELPDData, _circular_standard_deviation
+from .stats_utils import get_log_likelihood as _get_log_likelihood
+from .stats_utils import logsumexp as _logsumexp
+from .stats_utils import make_ufunc as _make_ufunc
+from .stats_utils import stats_variance_2d as svar
+from .stats_utils import wrap_xarray_ufunc as _wrap_xarray_ufunc
 
 _log = logging.getLogger(__name__)
 
@@ -335,7 +334,9 @@ def hpd(
 ):
     """Pending deprecation. Please refer to :func:`~arviz.hdi`."""
     # pylint: enable=unused-argument
-    warnings.warn(("hpd will be deprecated " "Please replace hdi"),)
+    warnings.warn(
+        ("hpd will be deprecated " "Please replace hdi"),
+    )
     return hdi(
         ary,
         hdi_prob,
@@ -545,13 +546,13 @@ def _hdi_multimodal(ary, hdi_prob, skipna, max_modes):
         ary = ary[~np.isnan(ary)]
 
     if ary.dtype.kind == "f":
-        density, lower, upper = _fast_kde(ary)
+        bins, density = _kde(ary)
+        lower, upper = bins[0], bins[-1]
         range_x = upper - lower
         dx = range_x / len(density)
-        bins = np.linspace(lower, upper, len(density))
     else:
-        bins = get_bins(ary)
-        _, density, _ = histogram(ary, bins=bins)
+        bins = _get_bins(ary)
+        _, density, _ = _histogram(ary, bins=bins)
         dx = np.diff(bins)[0]
 
     density *= dx
@@ -566,7 +567,7 @@ def _hdi_multimodal(ary, hdi_prob, skipna, max_modes):
     for i, interval in enumerate(intervals_splitted):
         if i == max_modes:
             warnings.warn(
-                "found more modes than {0}, returning only the first {0} modes", max_modes
+                "found more modes than {0}, returning only the first {0} modes".format(max_modes)
             )
             break
         if interval.size == 0:
@@ -993,6 +994,7 @@ def summary(
     kind: str = "all",
     round_to=None,
     include_circ=None,
+    circ_var_names=None,
     stat_funcs=None,
     extend=True,
     hdi_prob=None,
@@ -1027,8 +1029,11 @@ def summary(
         them.
     round_to: int
         Number of decimals used to round results. Defaults to 2. Use "none" to return raw numbers.
-    include_circ: bool
+    include_circ: boolean
         Whether to include circular statistics
+        deprecated: Please see circ_var_names
+    circ_var_names: list
+        A list of circular variables to compute circular stats for
     stat_funcs: dict
         A list of functions or a dict of functions with function names as keys used to calculate
         statistics. By default, the mean, standard deviation, simulation standard error, and
@@ -1116,6 +1121,12 @@ def summary(
            ...: )
 
     """
+    if include_circ:
+        warnings.warn(
+            "include_circ is deprecated and will be ignored. Use circ_var_names instead",
+            DeprecationWarning,
+        )
+
     if credible_interval:
         hdi_prob = credible_interval_warning(hdi_prob, hdi_prob)
 
@@ -1177,7 +1188,7 @@ def summary(
         hdi_lower = hdi_post.sel(hdi="lower", drop=True)
         hdi_higher = hdi_post.sel(hdi="higher", drop=True)
 
-    if include_circ:
+    if circ_var_names:
         nan_policy = "omit" if skipna else "propagate"
         circ_mean = xr.apply_ufunc(
             _make_ufunc(st.circmean),
@@ -1258,17 +1269,18 @@ def summary(
             metrics_names_ = metrics_names_[4:]
         metrics.extend(metrics_)
         metric_names.extend(metrics_names_)
-    if include_circ:
-        metrics.extend((circ_mean, circ_sd, circ_hdi_lower, circ_hdi_higher, circ_mcse))
-        metric_names.extend(
-            (
-                "circular_mean",
-                "circular_sd",
-                "circular_hdi_{:g}%".format(100 * alpha / 2),
-                "circular_hdi_{:g}%".format(100 * (1 - alpha / 2)),
-                "circular_mcse",
-            )
-        )
+
+    if circ_var_names:
+
+        if kind != "diagnostics":
+            for metric, circ_stat in zip(
+                # Replace only the first 5 statistics for their circular equivalent
+                metrics[:5],
+                (circ_mean, circ_sd, circ_hdi_lower, circ_hdi_higher, circ_mcse),
+            ):
+                for circ_var in circ_var_names:
+                    metric[circ_var] = circ_stat[circ_var]
+
     metrics.extend(extra_metrics)
     metric_names.extend(extra_metric_names)
     joined = (
