@@ -1,15 +1,18 @@
 """Stats-utility functions for ArviZ."""
-from collections.abc import Sequence
 import logging
 import warnings
-from copy import copy as _copy, deepcopy as _deepcopy
+from collections.abc import Sequence
+from copy import copy as _copy
+from copy import deepcopy as _deepcopy
 
 import numpy as np
 import pandas as pd
 from scipy.fftpack import next_fast_len
 from scipy.stats.mstats import mquantiles
 from xarray import apply_ufunc
+
 from ..utils import conditional_jit, conditional_vect
+from .density_utils import histogram as _histogram
 
 _log = logging.getLogger(__name__)
 
@@ -315,12 +318,6 @@ def logsumexp(ary, *, b=None, b_inv=None, axis=None, keepdims=False, out=None, c
     return out if out.shape else dtype(out)
 
 
-def rint(num):
-    """Round and change to ingeter."""
-    rnum = np.rint(num)  # pylint: disable=assignment-from-no-return
-    return int(rnum)
-
-
 def quantile(ary, q, axis=None, limit=None):
     """Use same quantile function as R (Type 7)."""
     if limit is None:
@@ -418,8 +415,8 @@ def get_log_likelihood(idata, var_name=None):
     else:
         try:
             log_likelihood = idata.log_likelihood[var_name]
-        except KeyError:
-            raise TypeError("No log likelihood data named {} found".format(var_name))
+        except KeyError as err:
+            raise TypeError("No log likelihood data named {} found".format(var_name)) from err
         return log_likelihood
 
 
@@ -437,11 +434,6 @@ Pareto k diagnostic values:
    (0.7, 1]   (bad)      {{4:{0}d}} {{8:6.1f}}%
    (1, Inf)   (very bad) {{5:{0}d}} {{9:6.1f}}%
 """
-SCALE_WARNING_FORMAT = """
-The scale is now log by default. Use 'scale' argument or 'stats.ic_scale' rcParam if
-you rely on a specific value.
-A higher log-score (or a lower deviance) indicates a model with better predictive
-accuracy."""
 SCALE_DICT = {"deviance": "deviance", "log": "elpd", "negative_log": "-elpd"}
 
 
@@ -472,13 +464,12 @@ class ELPDData(pd.Series):  # pylint: disable=too-many-ancestors
 
         if kind == "loo" and "pareto_k" in self:
             bins = np.asarray([-np.Inf, 0.5, 0.7, 1, np.Inf])
-            counts, *_ = histogram(self.pareto_k.values, bins)
+            counts, *_ = _histogram(self.pareto_k.values, bins)
             extended = POINTWISE_LOO_FMT.format(max(4, len(str(np.max(counts)))))
             extended = extended.format(
                 "Count", "Pct.", *[*counts, *(counts / np.sum(counts) * 100)]
             )
             base = "\n".join([base, extended])
-        base = "\n".join([base, SCALE_WARNING_FORMAT])
         return base
 
     def __repr__(self):
@@ -523,33 +514,6 @@ def stats_variance_2d(data, ddof=0, axis=1):
         return var
 
 
-@conditional_jit(cache=True)
-def histogram(data, bins, range_hist=None):
-    """Conditionally jitted histogram.
-
-    Parameters
-    ----------
-    data : array-like
-        Input data. Passed as first positional argument to ``np.histogram``.
-    bins : int or array-like
-        Passed as keyword argument ``bins`` to ``np.histogram``.
-    range_hist : (float, float), optional
-        Passed as keyword argument ``range`` to ``np.histogram``.
-
-    Returns
-    -------
-    hist : array
-        The number of counts per bin.
-    density : array
-        The density corresponding to each bin.
-    bin_edges : array
-        The edges of the bins used.
-    """
-    hist, bin_edges = np.histogram(data, bins=bins, range=range_hist)
-    hist_dens = hist / (hist.sum() * np.diff(bin_edges))
-    return hist, hist_dens, bin_edges
-
-
 @conditional_vect
 def _sqrt(a_a, b_b):
     return (a_a + b_b) ** 0.5
