@@ -1,35 +1,42 @@
 # pylint: disable=no-member, invalid-name, redefined-outer-name
 # pylint: disable=too-many-lines
-from collections import namedtuple
 import os
+from collections import namedtuple
+from copy import deepcopy
+from html import escape
 from typing import Dict
 from urllib.parse import urlunsplit
-from html import escape
+
 import numpy as np
 import pytest
-
 import xarray as xr
 from xarray.core.options import OPTIONS
+from xarray.testing import assert_identical
 
 from arviz import (
-    concat,
-    convert_to_inference_data,
-    convert_to_dataset,
-    from_dict,
-    from_netcdf,
-    to_netcdf,
-    load_arviz_data,
-    list_datasets,
-    clear_data_home,
     InferenceData,
+    clear_data_home,
+    concat,
+    convert_to_dataset,
+    convert_to_inference_data,
+    from_dict,
+    from_json,
+    from_netcdf,
+    list_datasets,
+    load_arviz_data,
+    to_netcdf,
 )
-from ...data.base import generate_dims_coords, make_attrs, dict_to_dataset
-from ...data.datasets import REMOTE_DATASETS, LOCAL_DATASETS, RemoteFileMetadata
+
+from ...data.base import dict_to_dataset, generate_dims_coords, make_attrs
+from ...data.datasets import LOCAL_DATASETS, REMOTE_DATASETS, RemoteFileMetadata
 from ..helpers import (  # pylint: disable=unused-import
     chains,
     check_multiple_attrs,
+    create_data_random,
+    data_random,
     draws,
     eight_schools_params,
+    models,
 )
 
 
@@ -309,7 +316,7 @@ def test_inference_concat_keeps_all_fields():
     assert not fails_c2
 
 
-class TestInferenceData:
+class TestInferenceData:  # pylint: disable=too-many-public-methods
     def test_addition(self):
         idata1 = from_dict(
             posterior={"A": np.random.randn(2, 10, 2), "B": np.random.randn(2, 10, 5, 2)}
@@ -323,15 +330,50 @@ class TestInferenceData:
         fails = check_multiple_attrs(test_dict, new_idata)
         assert not fails
 
+    def test_iter(self, models):
+        idata = models.model_1
+        for group in idata:
+            assert group in idata._groups_all  # pylint: disable=protected-access
+
+    def test_groups(self, models):
+        idata = models.model_1
+        for group in idata.groups():
+            assert group in idata._groups_all  # pylint: disable=protected-access
+
+    def test_values(self, models):
+        idata = models.model_1
+        datasets = idata.values()
+        for group in idata.groups():
+            assert group in idata._groups_all  # pylint: disable=protected-access
+            dataset = getattr(idata, group)
+            assert dataset in datasets
+
+    def test_items(self, models):
+        idata = models.model_1
+        for group, dataset in idata.items():
+            assert group in idata._groups_all  # pylint: disable=protected-access
+            assert dataset.equals(getattr(idata, group))
+
     @pytest.mark.parametrize("inplace", [True, False])
-    def test_sel(self, inplace):
-        data = np.random.normal(size=(4, 500, 8))
-        idata = from_dict(
-            posterior={"a": data[..., 0], "b": data},
-            sample_stats={"a": data[..., 0], "b": data},
-            observed_data={"b": data[0, 0, :]},
-            posterior_predictive={"a": data[..., 0], "b": data},
+    def test_extend_xr_method(self, data_random, inplace):
+        idata = data_random
+        idata_copy = deepcopy(idata)
+        kwargs = {"groups": "posterior_groups"}
+        if inplace:
+            idata_copy.sum(dim="draw", inplace=inplace, **kwargs)
+        else:
+            idata2 = idata_copy.sum(dim="draw", inplace=inplace, **kwargs)
+            assert idata2 is not idata_copy
+            idata_copy = idata2
+        assert_identical(idata_copy.posterior, idata.posterior.sum(dim="draw"))
+        assert_identical(
+            idata_copy.posterior_predictive, idata.posterior_predictive.sum(dim="draw")
         )
+        assert_identical(idata_copy.observed_data, idata.observed_data)
+
+    @pytest.mark.parametrize("inplace", [False, True])
+    def test_sel(self, data_random, inplace):
+        idata = data_random
         original_groups = getattr(idata, "_groups")
         ndraws = idata.posterior.draw.values.size
         kwargs = {"draw": slice(200, None), "chain": slice(None, None, 2), "b_dim_0": [1, 2, 7]}
@@ -428,11 +470,129 @@ class TestInferenceData:
         args, result = args_res
         ds = dict_to_dataset({"a": np.random.normal(size=(3, 10))})
         idata = InferenceData(
-            posterior=(ds, ds), sample_stats=(ds, ds), observed_data=ds, posterior_predictive=ds,
+            posterior=(ds, ds),
+            sample_stats=(ds, ds),
+            observed_data=ds,
+            posterior_predictive=ds,
         )
         group_names = idata._group_names(*args)  # pylint: disable=protected-access
         assert np.all([name in result for name in group_names])
 
+    @pytest.mark.parametrize("inplace", [False, True])
+    def test_isel(self, data_random, inplace):
+        idata = data_random
+        original_groups = getattr(idata, "_groups")
+        ndraws = idata.posterior.draw.values.size
+        kwargs = {"draw": slice(200, None), "chain": slice(None, None, 2), "b_dim_0": [1, 2, 7]}
+        if inplace:
+            idata.isel(inplace=inplace, **kwargs)
+        else:
+            idata2 = idata.isel(inplace=inplace, **kwargs)
+            assert idata2 is not idata
+            idata = idata2
+        groups = getattr(idata, "_groups")
+        assert np.all(np.isin(groups, original_groups))
+        for group in groups:
+            dataset = getattr(idata, group)
+            assert "b_dim_0" in dataset.dims
+            assert np.all(dataset.b_dim_0.values == np.array(kwargs["b_dim_0"]))
+            if group != "observed_data":
+                assert np.all(np.isin(["chain", "draw"], dataset.dims))
+                assert np.all(dataset.chain.values == np.arange(0, 4, 2))
+                assert np.all(dataset.draw.values == np.arange(200, ndraws))
+
+    def test_rename(self, data_random):
+        idata = data_random
+        original_groups = getattr(idata, "_groups")
+        renamed_idata = idata.rename({"b": "b_new"})
+        for group in original_groups:
+            xr_data = getattr(renamed_idata, group)
+            assert "b_new" in list(xr_data.data_vars)
+            assert "b" not in list(xr_data.data_vars)
+
+        renamed_idata = idata.rename({"b_dim_0": "b_new"})
+        for group in original_groups:
+            xr_data = getattr(renamed_idata, group)
+            assert "b_new" in list(xr_data.dims)
+            assert "b_dim_0" not in list(xr_data.dims)
+
+    def test_rename_vars(self, data_random):
+        idata = data_random
+        original_groups = getattr(idata, "_groups")
+        renamed_idata = idata.rename_vars({"b": "b_new"})
+        for group in original_groups:
+            xr_data = getattr(renamed_idata, group)
+            assert "b_new" in list(xr_data.data_vars)
+            assert "b" not in list(xr_data.data_vars)
+
+        renamed_idata = idata.rename_vars({"b_dim_0": "b_new"})
+        for group in original_groups:
+            xr_data = getattr(renamed_idata, group)
+            assert "b_new" not in list(xr_data.dims)
+            assert "b_dim_0" in list(xr_data.dims)
+
+    def test_rename_dims(self, data_random):
+        idata = data_random
+        original_groups = getattr(idata, "_groups")
+        renamed_idata = idata.rename_dims({"b_dim_0": "b_new"})
+        for group in original_groups:
+            xr_data = getattr(renamed_idata, group)
+            assert "b_new" in list(xr_data.dims)
+            assert "b_dim_0" not in list(xr_data.dims)
+
+        renamed_idata = idata.rename_dims({"b": "b_new"})
+        for group in original_groups:
+            xr_data = getattr(renamed_idata, group)
+            assert "b_new" not in list(xr_data.data_vars)
+            assert "b" in list(xr_data.data_vars)
+
+    def test_stack_unstack(self):
+        datadict = {
+            "a": np.random.randn(100),
+            "b": np.random.randn(1, 100, 10),
+            "c": np.random.randn(1, 100, 3, 4),
+        }
+        coords = {
+            "c1": np.arange(3),
+            "c99": np.arange(4),
+            "b1": np.arange(10),
+        }
+        dims = {"c": ["c1", "c99"], "b": ["b1"]}
+        dataset = from_dict(posterior=datadict, coords=coords, dims=dims)
+        assert_identical(
+            dataset.stack(z=["c1", "c99"]).posterior, dataset.posterior.stack(z=["c1", "c99"])
+        )
+        assert_identical(dataset.stack(z=["c1", "c99"]).unstack().posterior, dataset.posterior)
+        assert_identical(
+            dataset.stack(z=["c1", "c99"]).unstack(dim="z").posterior, dataset.posterior
+        )
+
+    def test_to_dict(self, models):
+        idata = models.model_1
+        test_data = from_dict(**idata.to_dict())
+        assert test_data
+        for group in idata._groups_all:  # pylint: disable=protected-access
+            xr_data = getattr(idata, group)
+            test_xr_data = getattr(test_data, group)
+            assert xr_data.equals(test_xr_data)
+
+    def test_to_dict_warmup(self):
+        idata = create_data_random(
+            groups=[
+                "posterior",
+                "sample_stats",
+                "observed_data",
+                "warmup_posterior",
+                "warmup_posterior_predictive",
+            ]
+        )
+        test_data = from_dict(**idata.to_dict(), save_warmup=True)
+        assert test_data
+        for group in idata._groups_all:  # pylint: disable=protected-access
+            xr_data = getattr(idata, group)
+            test_xr_data = getattr(test_data, group)
+            assert xr_data.equals(test_xr_data)
+
     @pytest.mark.parametrize("use", (None, "args", "kwargs"))
     def test_map(self, use):
         idata = load_arviz_data("centered_eight")
@@ -480,6 +640,67 @@ class TestInferenceData:
         assert escape(idata.__repr__()) in html
         xr.set_options(display_style=display_style)
 
+    def test_add_groups(self, data_random):
+        data = np.random.normal(size=(4, 500, 8))
+        idata = data_random
+        idata.add_groups({"prior": {"a": data[..., 0], "b": data}})
+        assert "prior" in idata._groups  # pylint: disable=protected-access
+        assert isinstance(idata.prior, xr.Dataset)
+        assert hasattr(idata, "prior")
+
+        idata.add_groups(warmup_posterior={"a": data[..., 0], "b": data})
+        assert "warmup_posterior" in idata._groups_all  # pylint: disable=protected-access
+        assert isinstance(idata.warmup_posterior, xr.Dataset)
+        assert hasattr(idata, "warmup_posterior")
+
+    def test_add_groups_warning(self, data_random):
+        data = np.random.normal(size=(4, 500, 8))
+        idata = data_random
+        with pytest.warns(UserWarning, match="The group.+not defined in the InferenceData scheme"):
+            idata.add_groups({"new_group": idata.posterior})
+        with pytest.warns(UserWarning, match="the default dims.+will be added automatically"):
+            idata.add_groups(constant_data={"a": data[..., 0], "b": data})
+        assert idata.new_group.equals(idata.posterior)
+
+    def test_add_groups_error(self, data_random):
+        idata = data_random
+        with pytest.raises(ValueError, match="One of.+must be provided."):
+            idata.add_groups()
+        with pytest.raises(ValueError, match="Arguments.+xr.Dataset, xr.Dataarray or dicts"):
+            idata.add_groups({"new_group": "new_group"})
+        with pytest.raises(ValueError, match="group.+already exists"):
+            idata.add_groups({"posterior": idata.posterior})
+
+    def test_extend(self, data_random):
+        idata = data_random
+        idata2 = create_data_random(
+            groups=["prior", "prior_predictive", "observed_data", "warmup_posterior"], seed=7
+        )
+        idata.extend(idata2)
+        assert "prior" in idata._groups_all  # pylint: disable=protected-access
+        assert "warmup_posterior" in idata._groups_all  # pylint: disable=protected-access
+        assert hasattr(idata, "prior")
+        assert hasattr(idata, "prior_predictive")
+        assert idata.prior.equals(idata2.prior)
+        assert not idata.observed_data.equals(idata2.observed_data)
+        assert idata.prior_predictive.equals(idata2.prior_predictive)
+
+        idata.extend(idata2, join="right")
+        assert idata.prior.equals(idata2.prior)
+        assert idata.observed_data.equals(idata2.observed_data)
+        assert idata.prior_predictive.equals(idata2.prior_predictive)
+
+    def test_extend_errors_warnings(self, data_random):
+        idata = data_random
+        idata2 = create_data_random(groups=["prior", "prior_predictive", "observed_data"], seed=7)
+        with pytest.raises(ValueError, match="Extending.+InferenceData objects only."):
+            idata.extend("something")
+        with pytest.raises(ValueError, match="join must be either"):
+            idata.extend(idata2, join="outer")
+        idata2.add_groups(new_group=idata2.prior)
+        with pytest.warns(UserWarning):
+            idata.extend(idata2)
+
 
 class TestNumpyToDataArray:
     def test_1d_dataset(self):
@@ -703,7 +924,7 @@ class TestDataDict:
         assert set(dataset.data_vars) == {"mu", "tau", "eta", "theta"}
         assert set(dataset.coords) == {"chain", "draw", "school"}
 
-    def get_inference_data(self, data, eight_schools_params):
+    def get_inference_data(self, data, eight_schools_params, save_warmup=False):
         return from_dict(
             posterior=data.obj,
             posterior_predictive=data.obj,
@@ -711,9 +932,19 @@ class TestDataDict:
             prior=data.obj,
             prior_predictive=data.obj,
             sample_stats_prior=data.obj,
+            warmup_posterior=data.obj,
+            warmup_posterior_predictive=data.obj,
+            predictions=data.obj,
             observed_data=eight_schools_params,
-            coords={"school": np.arange(8)},
+            coords={
+                "school": np.arange(8),
+            },
+            pred_coords={
+                "school_pred": np.arange(8),
+            },
             dims={"theta": ["school"], "eta": ["school"]},
+            pred_dims={"theta": ["school_pred"], "eta": ["school_pred"]},
+            save_warmup=save_warmup,
         )
 
     def test_inference_data(self, data, eight_schools_params):
@@ -736,6 +967,33 @@ class TestDataDict:
         self.check_var_names_coords_dims(inference_data.prior_predictive)
         self.check_var_names_coords_dims(inference_data.sample_stats_prior)
 
+        pred_dims = inference_data.predictions.dims["school_pred"]
+        assert pred_dims == 8
+
+    def test_inference_data_warmup(self, data, eight_schools_params):
+        inference_data = self.get_inference_data(data, eight_schools_params, save_warmup=True)
+        test_dict = {
+            "posterior": [],
+            "prior": [],
+            "sample_stats": [],
+            "posterior_predictive": [],
+            "prior_predictive": [],
+            "sample_stats_prior": [],
+            "observed_data": ["J", "y", "sigma"],
+            "warmup_posterior_predictive": [],
+            "warmup_posterior": [],
+        }
+        fails = check_multiple_attrs(test_dict, inference_data)
+        assert not fails
+        self.check_var_names_coords_dims(inference_data.posterior)
+        self.check_var_names_coords_dims(inference_data.posterior_predictive)
+        self.check_var_names_coords_dims(inference_data.sample_stats)
+        self.check_var_names_coords_dims(inference_data.prior)
+        self.check_var_names_coords_dims(inference_data.prior_predictive)
+        self.check_var_names_coords_dims(inference_data.sample_stats_prior)
+        self.check_var_names_coords_dims(inference_data.warmup_posterior)
+        self.check_var_names_coords_dims(inference_data.warmup_posterior_predictive)
+
     def test_inference_data_edge_cases(self):
         # create data
         log_likelihood = {
@@ -889,6 +1147,23 @@ class TestDataNetCDF:
         assert not os.path.exists(filepath)
 
 
+class TestJSON:
+    def test_json_converters(self, models):
+        idata = models.model_1
+
+        filepath = os.path.realpath("test.json")
+        idata.to_json(filepath)
+
+        idata_copy = from_json(filepath)
+        for group in idata._groups_all:  # pylint: disable=protected-access
+            xr_data = getattr(idata, group)
+            test_xr_data = getattr(idata_copy, group)
+            assert xr_data.equals(test_xr_data)
+
+        os.remove(filepath)
+        assert not os.path.exists(filepath)
+
+
 class TestConversions:
     def test_id_conversion_idempotent(self):
         stored = load_arviz_data("centered_eight")
