@@ -1,5 +1,5 @@
-"""Tests use the 'bokeh' backend."""
 # pylint: disable=redefined-outer-name,too-many-lines
+"""Tests use the 'bokeh' backend."""
 from copy import deepcopy
 
 import numpy as np
@@ -7,20 +7,13 @@ import pytest
 from pandas import DataFrame  # pylint: disable=wrong-import-position
 
 from ...data import from_dict, load_arviz_data  # pylint: disable=wrong-import-position
-from ..helpers import (  # pylint: disable=unused-import, wrong-import-position
-    create_model,
-    create_multidimensional_model,
-    eight_schools_params,
-    importorskip,
-    models,
-    multidim_models,
-)
-from ...rcparams import rc_context, rcParams  # pylint: disable=wrong-import-position
 from ...plots import (  # pylint: disable=wrong-import-position
     plot_autocorr,
+    plot_bpv,
     plot_compare,
     plot_density,
     plot_dist,
+    plot_dist_comparison,
     plot_elpd,
     plot_energy,
     plot_ess,
@@ -35,12 +28,21 @@ from ...plots import (  # pylint: disable=wrong-import-position
     plot_parallel,
     plot_posterior,
     plot_ppc,
-    plot_dist_comparison,
     plot_rank,
+    plot_separation,
     plot_trace,
     plot_violin,
 )
-from ...stats import compare, loo, waic, hdi  # pylint: disable=wrong-import-position
+from ...rcparams import rc_context, rcParams  # pylint: disable=wrong-import-position
+from ...stats import compare, hdi, loo, waic  # pylint: disable=wrong-import-position
+from ..helpers import (  # pylint: disable=unused-import, wrong-import-position
+    create_model,
+    create_multidimensional_model,
+    eight_schools_params,
+    importorskip,
+    models,
+    multidim_models,
+)
 
 # Skip tests if bokeh not installed
 bkp = importorskip("bokeh.plotting")  # pylint: disable=invalid-name
@@ -98,10 +100,20 @@ def test_plot_density_discrete(discrete_model):
 
 def test_plot_density_no_subset():
     """Test plot_density works when variables are not subset of one another (#1093)."""
-    model_ab = from_dict({"a": np.random.normal(size=200), "b": np.random.normal(size=200),})
-    model_bc = from_dict({"b": np.random.normal(size=200), "c": np.random.normal(size=200),})
+    model_ab = from_dict(
+        {
+            "a": np.random.normal(size=200),
+            "b": np.random.normal(size=200),
+        }
+    )
+    model_bc = from_dict(
+        {
+            "b": np.random.normal(size=200),
+            "c": np.random.normal(size=200),
+        }
+    )
     axes = plot_density([model_ab, model_bc])
-    assert axes.shape[0] == 3
+    assert axes.size == 3
 
 
 def test_plot_density_bad_kwargs(models):
@@ -121,6 +133,22 @@ def test_plot_density_bad_kwargs(models):
         plot_density(obj, hdi_prob=2, backend="bokeh", show=False)
 
 
+@pytest.mark.parametrize(
+    "kwargs",
+    [
+        {},
+        {"y_hat_line": True},
+        {"expected_events": True},
+        {"y_hat_line_kwargs": {"linestyle": "dotted"}},
+        {"exp_events_kwargs": {"marker": "o"}},
+    ],
+)
+def test_plot_separation(kwargs):
+    idata = load_arviz_data("classification10d")
+    ax = plot_separation(idata=idata, y="outcome", backend="bokeh", show=False, **kwargs)
+    assert ax
+
+
 @pytest.mark.parametrize(
     "kwargs",
     [
@@ -190,7 +218,21 @@ def test_plot_kde_cumulative(continuous_model, kwargs):
     assert axes
 
 
-@pytest.mark.parametrize("kwargs", [{"kind": "hist"}, {"kind": "kde"}])
+@pytest.mark.parametrize(
+    "kwargs",
+    [
+        {"kind": "hist"},
+        {"kind": "kde"},
+        {"is_circular": False},
+        {"is_circular": False, "kind": "hist"},
+        {"is_circular": True},
+        {"is_circular": True, "kind": "hist"},
+        {"is_circular": "radians"},
+        {"is_circular": "radians", "kind": "hist"},
+        {"is_circular": "degrees"},
+        {"is_circular": "degrees", "kind": "hist"},
+    ],
+)
 def test_plot_dist(continuous_model, kwargs):
     axes = plot_dist(continuous_model["x"], backend="bokeh", show=False, **kwargs)
     assert axes
@@ -435,12 +477,23 @@ def test_plot_ess_no_divergences(models):
         ({"var_names": "mu", "rope": (-1, 1)}, 1),
         ({"r_hat": True, "quartiles": False}, 2),
         ({"var_names": ["mu"], "colors": "black", "ess": True, "combined": True}, 2),
+        (
+            {
+                "kind": "ridgeplot",
+                "ridgeplot_truncate": False,
+                "ridgeplot_quantiles": [0.25, 0.5, 0.75],
+            },
+            1,
+        ),
         ({"kind": "ridgeplot", "r_hat": True, "ess": True}, 3),
         ({"kind": "ridgeplot", "r_hat": True, "ess": True, "ridgeplot_alpha": 0}, 3),
         (
             {
                 "var_names": ["mu", "tau"],
-                "rope": {"mu": [{"rope": (-0.1, 0.1)}], "tau": [{"rope": (0.2, 0.5)}]},
+                "rope": {
+                    "mu": [{"rope": (-0.1, 0.1)}],
+                    "theta": [{"school": "Choate", "rope": (0.2, 0.5)}],
+                },
             },
             1,
         ),
@@ -964,5 +1017,32 @@ def test_plot_rank(models, kwargs):
 
 
 def test_plot_dist_comparison_warn(models):
-    with pytest.raises(NotImplementedError, match="The bokeh backend.+Use matplotlib bakend."):
+    with pytest.raises(NotImplementedError, match="The bokeh backend.+Use matplotlib backend."):
         plot_dist_comparison(models.model_1, backend="bokeh")
+
+
+@pytest.mark.parametrize(
+    "kwargs",
+    [
+        {},
+        {"reference": "analytical"},
+        {"kind": "p_value"},
+        {"kind": "t_stat", "t_stat": "std"},
+        {"kind": "t_stat", "t_stat": 0.5, "bpv": True},
+    ],
+)
+def test_plot_bpv(models, kwargs):
+    axes = plot_bpv(models.model_1, backend="bokeh", show=False, **kwargs)
+    assert axes.shape
+
+
+def test_plot_bpv_discrete():
+    fake_obs = {"a": np.random.poisson(2.5, 100)}
+    fake_pp = {"a": np.random.poisson(2.5, (1, 10, 100))}
+    fake_model = from_dict(posterior_predictive=fake_pp, observed_data=fake_obs)
+    axes = plot_bpv(
+        fake_model,
+        backend="bokeh",
+        show=False,
+    )
+    assert axes.shape
