@@ -2,49 +2,52 @@
 # pylint: disable=redefined-outer-name,too-many-lines
 import os
 from copy import deepcopy
+
 import matplotlib.pyplot as plt
+import numpy as np
+import pytest
 from matplotlib import animation
 from pandas import DataFrame
 from scipy.stats import gaussian_kde
-import numpy as np
-import pytest
 
 from ...data import from_dict, load_arviz_data
-from ...stats import compare, loo, waic, hdi
-from ..helpers import (  # pylint: disable=unused-import
-    eight_schools_params,
-    models,
-    create_model,
-    multidim_models,
-    create_multidimensional_model,
-)
-from ...rcparams import rcParams, rc_context
 from ...plots import (
+    plot_autocorr,
+    plot_bpv,
+    plot_compare,
     plot_density,
-    plot_trace,
+    plot_dist,
+    plot_dist_comparison,
+    plot_elpd,
     plot_energy,
     plot_ess,
-    plot_posterior,
-    plot_autocorr,
     plot_forest,
-    plot_parallel,
-    plot_pair,
+    plot_hdi,
     plot_joint,
-    plot_dist_comparison,
-    plot_ppc,
-    plot_violin,
-    plot_compare,
     plot_kde,
     plot_khat,
-    plot_hdi,
-    plot_dist,
-    plot_rank,
-    plot_elpd,
     plot_loo_pit,
     plot_mcse,
+    plot_pair,
+    plot_parallel,
+    plot_posterior,
+    plot_ppc,
+    plot_rank,
+    plot_separation,
+    plot_trace,
+    plot_violin,
 )
+from ...rcparams import rc_context, rcParams
+from ...stats import compare, hdi, loo, waic
+from ...stats.density_utils import kde as _kde
 from ...utils import _cov
-from ...numeric_utils import _fast_kde
+from ..helpers import (  # pylint: disable=unused-import
+    create_model,
+    create_multidimensional_model,
+    eight_schools_params,
+    models,
+    multidim_models,
+)
 
 rcParams["data.load"] = "eager"
 
@@ -90,6 +93,16 @@ def fig_ax():
     return fig, ax
 
 
+@pytest.fixture(scope="module")
+def data_random():
+    return np.random.randint(1, 100, size=20)
+
+
+@pytest.fixture(scope="module")
+def data_list():
+    return list(range(11, 31))
+
+
 @pytest.mark.parametrize(
     "kwargs",
     [
@@ -109,23 +122,30 @@ def fig_ax():
 def test_plot_density_float(models, kwargs):
     obj = [getattr(models, model_fit) for model_fit in ["model_1", "model_2"]]
     axes = plot_density(obj, **kwargs)
-    if "ax" in kwargs:
-        assert axes.shape == (6, 3)
-    else:
-        assert axes.shape[0] >= 18
+    assert axes.shape == (6, 3)
 
 
 def test_plot_density_discrete(discrete_model):
     axes = plot_density(discrete_model, shade=0.9)
-    assert axes.shape[0] == 2
+    assert axes.size == 2
 
 
 def test_plot_density_no_subset():
     """Test plot_density works when variables are not subset of one another (#1093)."""
-    model_ab = from_dict({"a": np.random.normal(size=200), "b": np.random.normal(size=200),})
-    model_bc = from_dict({"b": np.random.normal(size=200), "c": np.random.normal(size=200),})
+    model_ab = from_dict(
+        {
+            "a": np.random.normal(size=200),
+            "b": np.random.normal(size=200),
+        }
+    )
+    model_bc = from_dict(
+        {
+            "b": np.random.normal(size=200),
+            "c": np.random.normal(size=200),
+        }
+    )
     axes = plot_density([model_ab, model_bc])
-    assert axes.shape[0] == 3
+    assert axes.size == 3
 
 
 def test_plot_density_bad_kwargs(models):
@@ -140,6 +160,22 @@ def test_plot_density_bad_kwargs(models):
         plot_density(obj, hdi_prob=2)
 
 
+@pytest.mark.parametrize(
+    "kwargs",
+    [
+        {},
+        {"y_hat_line": True},
+        {"expected_events": True},
+        {"y_hat_line_kwargs": {"linestyle": "dotted"}},
+        {"exp_events_kwargs": {"marker": "o"}},
+    ],
+)
+def test_plot_separation(kwargs):
+    idata = load_arviz_data("classification10d")
+    ax = plot_separation(idata=idata, y="outcome", **kwargs)
+    assert ax
+
+
 @pytest.mark.parametrize(
     "kwargs",
     [
@@ -155,6 +191,8 @@ def test_plot_density_bad_kwargs(models):
         {"kind": "rank_bars"},
         {"lines": [("mu", {}, [1, 2])]},
         {"lines": [("mu", {}, 8)]},
+        {"circ_var_names": ["mu"]},
+        {"circ_var_units": "degrees"},
     ],
 )
 def test_plot_trace(models, kwargs):
@@ -163,10 +201,12 @@ def test_plot_trace(models, kwargs):
 
 
 @pytest.mark.parametrize(
-    "compact", [True, False],
+    "compact",
+    [True, False],
 )
 @pytest.mark.parametrize(
-    "combined", [True, False],
+    "combined",
+    [True, False],
 )
 def test_plot_trace_legend(compact, combined):
     idata = load_arviz_data("rugby")
@@ -226,12 +266,24 @@ def test_plot_trace_futurewarning(models, prop):
         ({"var_names": "mu", "rope": (-1, 1)}, 1),
         ({"r_hat": True, "quartiles": False}, 2),
         ({"var_names": ["mu"], "colors": "C0", "ess": True, "combined": True}, 2),
+        (
+            {
+                "kind": "ridgeplot",
+                "ridgeplot_truncate": False,
+                "ridgeplot_quantiles": [0.25, 0.5, 0.75],
+            },
+            1,
+        ),
+        ({"kind": "ridgeplot", "r_hat": True, "ess": True}, 3),
         ({"kind": "ridgeplot", "r_hat": True, "ess": True}, 3),
         ({"kind": "ridgeplot", "r_hat": True, "ess": True, "ridgeplot_alpha": 0}, 3),
         (
             {
-                "var_names": ["mu", "tau"],
-                "rope": {"mu": [{"rope": (-0.1, 0.1)}], "tau": [{"rope": (0.2, 0.5)}]},
+                "var_names": ["mu", "theta"],
+                "rope": {
+                    "mu": [{"rope": (-0.1, 0.1)}],
+                    "theta": [{"school": "Choate", "rope": (0.2, 0.5)}],
+                },
             },
             1,
         ),
@@ -241,7 +293,7 @@ def test_plot_forest(models, model_fits, args_expected):
     obj = [getattr(models, model_fit) for model_fit in model_fits]
     args, expected = args_expected
     axes = plot_forest(obj, **args)
-    assert axes.shape == (expected,)
+    assert axes.size == expected
 
 
 def test_plot_forest_rope_exception():
@@ -338,6 +390,10 @@ def test_plot_joint_bad(models):
         },
         {"contour": False},
         {"contour": False, "pcolormesh_kwargs": {"cmap": "plasma"}},
+        {"is_circular": False},
+        {"is_circular": True},
+        {"is_circular": "radians"},
+        {"is_circular": "degrees"},
     ],
 )
 def test_plot_kde(continuous_model, kwargs):
@@ -369,12 +425,36 @@ def test_plot_kde_cumulative(continuous_model, kwargs):
     assert axes
 
 
-@pytest.mark.parametrize("kwargs", [{"kind": "hist"}, {"kind": "kde"}])
+@pytest.mark.parametrize(
+    "kwargs",
+    [
+        {"kind": "hist"},
+        {"kind": "kde"},
+        {"is_circular": False},
+        {"is_circular": False, "kind": "hist"},
+        {"is_circular": True},
+        {"is_circular": True, "kind": "hist"},
+        {"is_circular": "radians"},
+        {"is_circular": "radians", "kind": "hist"},
+        {"is_circular": "degrees"},
+        {"is_circular": "degrees", "kind": "hist"},
+    ],
+)
 def test_plot_dist(continuous_model, kwargs):
     axes = plot_dist(continuous_model["x"], **kwargs)
     assert axes
 
 
+def test_plot_dist_hist(data_random):
+    axes = plot_dist(data_random, hist_kwargs=dict(bins=30))
+    assert axes
+
+
+def test_list_conversion(data_list):
+    axes = plot_dist(data_list, hist_kwargs=dict(bins=30))
+    assert axes
+
+
 @pytest.mark.parametrize(
     "kwargs",
     [
@@ -654,15 +734,23 @@ def test_non_linux_blit(models, monkeypatch, system, caplog):
     assert anim
 
 
-def test_plot_ppc_grid(models):
-    axes = plot_ppc(models.model_1, kind="scatter", flatten=[])
-    assert len(axes) == 8
-    axes = plot_ppc(models.model_1, kind="scatter", flatten=[], coords={"obs_dim": [1, 2, 3]})
-    assert len(axes) == 3
-    axes = plot_ppc(
-        models.model_1, kind="scatter", flatten=["obs_dim"], coords={"obs_dim": [1, 2, 3]}
-    )
-    assert len(axes) == 1
+@pytest.mark.parametrize(
+    "kwargs",
+    [
+        {"flatten": []},
+        {"flatten": [], "coords": {"obs_dim": [1, 2, 3]}},
+        {"flatten": ["obs_dim"], "coords": {"obs_dim": [1, 2, 3]}},
+    ],
+)
+def test_plot_ppc_grid(models, kwargs):
+    axes = plot_ppc(models.model_1, kind="scatter", **kwargs)
+    if not kwargs.get("flatten") and not kwargs.get("coords"):
+        assert axes.size == 8
+    elif not kwargs.get("flatten"):
+        assert axes.size == 3
+    else:
+        assert not isinstance(axes, np.ndarray)
+        assert np.ravel(axes).size == 1
 
 
 @pytest.mark.parametrize("kind", ["kde", "cumulative", "scatter"])
@@ -681,7 +769,7 @@ def test_plot_ppc_ax(models, kind, fig_ax):
     """Test ax argument of plot_ppc."""
     _, ax = fig_ax
     axes = plot_ppc(models.model_1, kind=kind, ax=ax)
-    assert axes[0] is ax
+    assert np.asarray(axes).item(0) is ax
 
 
 @pytest.mark.skipif(
@@ -730,23 +818,25 @@ def test_plot_autocorr_short_chain():
 
 def test_plot_autocorr_uncombined(models):
     axes = plot_autocorr(models.model_1, combined=False)
-    assert axes.shape[0] == 1
+    assert axes.size
     max_subplots = (
         np.inf if rcParams["plot.max_subplots"] is None else rcParams["plot.max_subplots"]
     )
-    assert axes.shape[1] == min(72, max_subplots)
+    assert axes.size == min(72, max_subplots)
 
 
 def test_plot_autocorr_combined(models):
     axes = plot_autocorr(models.model_1, combined=True)
-    assert axes.shape[0] == 1
-    assert axes.shape[1] == 18
+    assert axes.size == 18
 
 
-@pytest.mark.parametrize("var_names", (None, "mu", ["mu", "tau"]))
+@pytest.mark.parametrize("var_names", (None, "mu", ["mu"], ["mu", "tau"]))
 def test_plot_autocorr_var_names(models, var_names):
     axes = plot_autocorr(models.model_1, var_names=var_names, combined=True)
-    assert axes.shape
+    if (isinstance(var_names, list) and len(var_names) == 1) or isinstance(var_names, str):
+        assert not isinstance(axes, np.ndarray)
+    else:
+        assert axes.shape
 
 
 @pytest.mark.parametrize(
@@ -762,7 +852,11 @@ def test_plot_autocorr_var_names(models, var_names):
 )
 def test_plot_rank(models, kwargs):
     axes = plot_rank(models.model_1, **kwargs)
-    assert axes.shape
+    var_names = kwargs.get("var_names", [])
+    if isinstance(var_names, str):
+        assert not isinstance(axes, np.ndarray)
+    else:
+        assert axes.shape
 
 
 @pytest.mark.parametrize(
@@ -793,7 +887,10 @@ def test_plot_rank(models, kwargs):
 )
 def test_plot_posterior(models, kwargs):
     axes = plot_posterior(models.model_1, **kwargs)
-    assert axes.shape
+    if isinstance(kwargs.get("var_names"), str):
+        assert not isinstance(axes, np.ndarray)
+    else:
+        assert axes.shape
 
 
 @pytest.mark.parametrize("kwargs", [{}, {"point_estimate": "mode"}, {"bins": None, "kind": "hist"}])
@@ -814,7 +911,7 @@ def test_plot_posterior_bad(models):
 @pytest.mark.parametrize("point_estimate", ("mode", "mean", "median"))
 def test_plot_posterior_point_estimates(models, point_estimate):
     axes = plot_posterior(models.model_1, var_names=("mu", "tau"), point_estimate=point_estimate)
-    assert axes.shape == (2,)
+    assert axes.size == 2
 
 
 @pytest.mark.parametrize(
@@ -894,23 +991,25 @@ def test_plot_hdi_dataset_error(models):
 
 
 @pytest.mark.parametrize("limits", [(-10.0, 10.0), (-5, 5), (None, None)])
-def test_fast_kde_scipy(limits):
+def test_kde_scipy(limits):
+    """
+    Evaluates if sum of density is the same for our implementation
+    and the implementation in scipy
+    """
     data = np.random.normal(0, 1, 10000)
-    if limits[0] is None:
-        x = np.linspace(data.min(), data.max(), 200)  # pylint: disable=no-member
-    else:
-        x = np.linspace(*limits, 500)
-    density = gaussian_kde(data).evaluate(x)
-    density_fast = _fast_kde(data, xmin=limits[0], xmax=limits[1])[0]
-
-    np.testing.assert_almost_equal(density_fast.sum(), density.sum(), 1)
+    grid, density_own = _kde(data, custom_lims=limits)
+    density_sp = gaussian_kde(data).evaluate(grid)
+    np.testing.assert_almost_equal(density_own.sum(), density_sp.sum(), 1)
 
 
 @pytest.mark.parametrize("limits", [(-10.0, 10.0), (-5, 5), (None, None)])
-def test_fast_kde_cumulative(limits):
+def test_kde_cumulative(limits):
+    """
+    Evaluates if last value of cumulative density is 1
+    """
     data = np.random.normal(0, 1, 1000)
-    density_fast = _fast_kde(data, xmin=limits[0], xmax=limits[1], cumulative=True)[0]
-    np.testing.assert_almost_equal(round(density_fast[-1], 3), 1)
+    density = _kde(data, custom_lims=limits, cumulative=True)[1]
+    np.testing.assert_almost_equal(round(density[-1], 3), 1)
 
 
 @pytest.mark.parametrize(
@@ -1280,9 +1379,35 @@ def test_plot_dist_comparison(models, kwargs):
 
 def test_plot_dist_comparison_different_vars():
     data = from_dict(
-        posterior={"x": np.random.randn(4, 100, 30),}, prior={"x_hat": np.random.randn(4, 100, 30)},
+        posterior={
+            "x": np.random.randn(4, 100, 30),
+        },
+        prior={"x_hat": np.random.randn(4, 100, 30)},
     )
     with pytest.raises(KeyError):
         plot_dist_comparison(data, var_names="x")
     ax = plot_dist_comparison(data, var_names=[["x_hat"], ["x"]])
     assert np.all(ax)
+
+
+@pytest.mark.parametrize(
+    "kwargs",
+    [
+        {},
+        {"reference": "analytical"},
+        {"kind": "p_value"},
+        {"kind": "t_stat", "t_stat": "std"},
+        {"kind": "t_stat", "t_stat": 0.5, "bpv": True},
+    ],
+)
+def test_plot_bpv(models, kwargs):
+    axes = plot_bpv(models.model_1, **kwargs)
+    assert not isinstance(axes, np.ndarray)
+
+
+def test_plot_bpv_discrete():
+    fake_obs = {"a": np.random.poisson(2.5, 100)}
+    fake_pp = {"a": np.random.poisson(2.5, (1, 10, 100))}
+    fake_model = from_dict(posterior_predictive=fake_pp, observed_data=fake_obs)
+    axes = plot_bpv(fake_model)
+    assert not isinstance(axes, np.ndarray)
