@@ -1,26 +1,23 @@
 """Tests for stats_utils."""
 #  pylint: disable=no-member
 import numpy as np
-from numpy.testing import assert_array_almost_equal
 import pytest
+from numpy.testing import assert_array_almost_equal
 from scipy.special import logsumexp
 from scipy.stats import circstd
 
-from ...data import load_arviz_data, from_dict
+from ...data import from_dict, load_arviz_data
+from ...stats.density_utils import histogram
 from ...stats.stats_utils import (
-    logsumexp as _logsumexp,
-    make_ufunc,
-    wrap_xarray_ufunc,
-    not_valid,
     ELPDData,
-    stats_variance_2d,
-    histogram,
-    _sqrt,
     _angle,
     _circfunc,
     _circular_standard_deviation,
+    _sqrt,
     get_log_likelihood,
 )
+from ...stats.stats_utils import logsumexp as _logsumexp
+from ...stats.stats_utils import make_ufunc, not_valid, stats_variance_2d, wrap_xarray_ufunc
 
 
 @pytest.mark.parametrize("ary_dtype", [np.float64, np.float32, np.int32, np.int64])
@@ -276,7 +273,11 @@ def test_get_log_likelihood():
 
 
 def test_get_log_likelihood_warning():
-    idata = from_dict(sample_stats={"log_likelihood": np.random.normal(size=(4, 100, 6)),})
+    idata = from_dict(
+        sample_stats={
+            "log_likelihood": np.random.normal(size=(4, 100, 6)),
+        }
+    )
     with pytest.warns(DeprecationWarning):
         get_log_likelihood(idata)
 
@@ -294,7 +295,10 @@ def test_get_log_likelihood_no_var_name():
 
 def test_get_log_likelihood_no_group():
     idata = from_dict(
-        posterior={"a": np.random.normal(size=(4, 100)), "b": np.random.normal(size=(4, 100)),}
+        posterior={
+            "a": np.random.normal(size=(4, 100)),
+            "b": np.random.normal(size=(4, 100)),
+        }
     )
     with pytest.raises(TypeError, match="log likelihood not found"):
         get_log_likelihood(idata)
@@ -378,5 +382,6 @@ def test_circular_standard_deviation_1d(data):
     high = 8
     low = 4
     assert np.allclose(
-        _circular_standard_deviation(data, high=high, low=low), circstd(data, high=high, low=low),
+        _circular_standard_deviation(data, high=high, low=low),
+        circstd(data, high=high, low=low),
     )
