@@ -142,6 +142,36 @@ def create_multidimensional_model(seed=10):
     return model
 
 
+def create_data_random(groups=None, seed=10):
+    """Create InferenceData object using random data."""
+    if groups is None:
+        groups = ["posterior", "sample_stats", "observed_data", "posterior_predictive"]
+    rng = np.random.default_rng(seed)
+    data = rng.normal(size=(4, 500, 8))
+    idata_dict = dict(
+        posterior={"a": data[..., 0], "b": data},
+        sample_stats={"a": data[..., 0], "b": data},
+        observed_data={"b": data[0, 0, :]},
+        posterior_predictive={"a": data[..., 0], "b": data},
+        prior={"a": data[..., 0], "b": data},
+        prior_predictive={"a": data[..., 0], "b": data},
+        warmup_posterior={"a": data[..., 0], "b": data},
+        warmup_posterior_predictive={"a": data[..., 0], "b": data},
+        warmup_prior={"a": data[..., 0], "b": data},
+    )
+    idata = from_dict(
+        **{group: ary for group, ary in idata_dict.items() if group in groups}, save_warmup=True
+    )
+    return idata
+
+
+@pytest.fixture()
+def data_random():
+    """Fixture containing InferenceData object using random data."""
+    idata = create_data_random()
+    return idata
+
+
 @pytest.fixture(scope="module")
 def models():
     """Fixture containing 2 mock inference data instances for testing."""
@@ -372,8 +402,8 @@ def numpyro_schools_model(data, draws, chains):
 
 def tfp_schools_model(num_schools, treatment_stddevs):
     """Non-centered eight schools model for tfp."""
-    import tensorflow_probability.python.edward2 as ed
     import tensorflow as tf
+    import tensorflow_probability.python.edward2 as ed
 
     if int(tf.__version__[0]) > 1:
         import tensorflow.compat.v1 as tf  # pylint: disable=import-error
@@ -394,9 +424,9 @@ def tfp_schools_model(num_schools, treatment_stddevs):
 
 def tfp_noncentered_schools(data, draws, chains):
     """Non-centered eight schools implementation for tfp."""
+    import tensorflow as tf
     import tensorflow_probability as tfp
     import tensorflow_probability.python.edward2 as ed
-    import tensorflow as tf
 
     if int(tf.__version__[0]) > 1:
         import tensorflow.compat.v1 as tf  # pylint: disable=import-error
@@ -583,9 +613,9 @@ def pystan_version():
         version = int(pystan.__version__[0])
     except ImportError:
         try:
-            import stan as pystan  # pylint: disable=import-error
+            import stan  # pylint: disable=import-error
 
-            version = int(pystan.__version__[0])
+            version = int(stan.__version__[0])
         except ImportError:
             version = None
     return version
