@@ -1,17 +1,20 @@
 # pylint: disable=too-many-nested-blocks
 """General utilities."""
-import importlib
 import functools
+import importlib
 import re
 import warnings
+from functools import lru_cache
 
 import matplotlib.pyplot as plt
 import numpy as np
-import xarray as xr
-
+import pkg_resources
 from numpy import newaxis
+
 from .rcparams import rcParams
 
+STATIC_FILES = ("static/html/icons-svg-inline.html", "static/css/style.css")
+
 
 def _var_names(var_names, data, filter_vars=None):
     """Handle var_names input across arviz.
@@ -56,7 +59,7 @@ def _var_names(var_names, data, filter_vars=None):
             var_names = _subset_list(var_names, all_vars, filter_items=filter_vars, warn=False)
         except KeyError as err:
             msg = " ".join(("var names:", f"{err}", "in dataset"))
-            raise KeyError(msg)
+            raise KeyError(msg) from err
     return var_names
 
 
@@ -225,7 +228,7 @@ class interactive_backend:  # pylint: disable=invalid-name
             raise ImportError(
                 "The exception below was risen while importing Ipython, this "
                 "context manager can only be used inside ipython sessions:\n{}".format(err)
-            )
+            ) from err
         self.ipython = get_ipython()
         if self.ipython is None:
             raise EnvironmentError("This context manager can only be used inside ipython sessions")
@@ -391,17 +394,19 @@ def expand_dims(x):
     return x.reshape(shape[:0] + (1,) + shape[0:])
 
 
-@conditional_jit(cache=True)
+@conditional_jit(cache=True, nopython=True)
 def _dot(x, y):
     return np.dot(x, y)
 
 
+@conditional_jit(cache=True, nopython=True)
 def _cov_1d(x):
     x = x - x.mean(axis=0)
     ddof = x.shape[0] - 1
     return np.dot(x.T, x.conj()) / ddof
 
 
+@conditional_jit(cache=True)
 def _cov(data):
     if data.ndim == 1:
         return _cov_1d(data)
@@ -422,7 +427,7 @@ def _cov(data):
         raise ValueError("{} dimension arrays are not supported".format(data.ndim))
 
 
-@conditional_jit
+@conditional_jit(nopython=True)
 def full(shape, x, dtype=None):
     """Jitting numpy full."""
     return np.full(shape, x, dtype=dtype)
@@ -623,9 +628,11 @@ def get_coords(data, coords):
         try:
             return data.sel(**coords)
 
-        except ValueError:
+        except ValueError as err:
             invalid_coords = set(coords.keys()) - set(data.coords.keys())
-            raise ValueError("Coords {} are invalid coordinate keys".format(invalid_coords))
+            raise ValueError(
+                "Coords {} are invalid coordinate keys".format(invalid_coords)
+            ) from err
 
         except KeyError as err:
             raise KeyError(
@@ -634,7 +641,7 @@ def get_coords(data, coords):
                     "Check that coords structure is correct and"
                     " dimensions are valid. {}"
                 ).format(err)
-            )
+            ) from err
     if not isinstance(coords, (list, tuple)):
         coords = [coords] * len(data)
     data_subset = []
@@ -642,9 +649,9 @@ def get_coords(data, coords):
         try:
             data_subset.append(get_coords(datum, coords_dict))
         except ValueError as err:
-            raise ValueError("Error in data[{}]: {}".format(idx, err))
+            raise ValueError("Error in data[{}]: {}".format(idx, err)) from err
         except KeyError as err:
-            raise KeyError("Error in data[{}]: {}".format(idx, err))
+            raise KeyError("Error in data[{}]: {}".format(idx, err)) from err
     return data_subset
 
 
@@ -667,6 +674,15 @@ def credible_interval_warning(credible_interval, hdi_prob):
     return hdi_prob
 
 
+@lru_cache(None)
+def _load_static_files():
+    """Lazily load the resource files into memory the first time they are needed.
+
+    Clone from xarray.core.formatted_html_template.
+    """
+    return [pkg_resources.resource_string("arviz", fname).decode("utf8") for fname in STATIC_FILES]
+
+
 class HtmlTemplate:
     """Contain html templates for InferenceData repr."""
 
@@ -692,5 +708,24 @@ class HtmlTemplate:
                   </div>
             </li>
             """
+    _, css_style = _load_static_files()  # pylint: disable=protected-access
     specific_style = ".xr-wrap{width:700px!important;}"
-    css_template = f"<style> {xr.core.formatting_html.CSS_STYLE}{specific_style} </style>"
+    css_template = f"<style> {css_style}{specific_style} </style>"
+
+
+def either_dict_or_kwargs(
+    pos_kwargs,
+    kw_kwargs,
+    func_name,
+):
+    """Clone from xarray.core.utils."""
+    if pos_kwargs is not None:
+        if not hasattr(pos_kwargs, "keys") and hasattr(pos_kwargs, "__getitem__"):
+            raise ValueError("the first argument to .%s must be a dictionary" % func_name)
+        if kw_kwargs:
+            raise ValueError(
+                "cannot specify both keyword and positional " "arguments to .%s" % func_name
+            )
+        return pos_kwargs
+    else:
+        return kw_kwargs
